@@ -1,5 +1,5 @@
 /*
- * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
@@ -106,21 +106,19 @@ void gtranslator_actions_set_up_default()
 	insert_action(ACT_FIND, the_edit_menu[7], the_navibar[8]);
 	insert_action(ACT_FIND_AGAIN, the_edit_menu[8], NONE);
 	insert_action(ACT_REPLACE, the_edit_menu[9], the_navibar[9]);
-	insert_action(ACT_QUERY, the_edit_menu[10], the_navibar[10]);
-	insert_action(ACT_HEADER, the_edit_menu[12], the_toolbar[6]);
-	insert_action(ACT_COMMENT, the_edit_menu[14], NONE);
-	insert_action(ACT_COPY_MSGID2MSGSTR, the_edit_menu[16], NONE);
+	insert_action(ACT_QUERY, the_edit_menu[11], the_navibar[10]);
+	insert_action(ACT_HEADER, the_edit_menu[13], the_toolbar[6]);
+	insert_action(ACT_COMMENT, the_edit_menu[15], NONE);
+	insert_action(ACT_COPY_MSGID2MSGSTR, the_edit_menu[17], NONE);
+	insert_action(ACT_FUZZY, the_edit_menu[19], NONE);
 	/*-----------------------------------------------------------*/
-	insert_action(ACT_FIRST, the_messages_menu[0], the_navibar[0]);
-	insert_action(ACT_BACK, the_messages_menu[1], the_navibar[1]);
-	insert_action(ACT_NEXT, the_messages_menu[3], the_navibar[3]);
-	insert_action(ACT_LAST, the_messages_menu[4], the_navibar[4]);
-	insert_action(ACT_GOTO, the_messages_menu[6], the_navibar[7]);
-	insert_action(ACT_NEXT_FUZZY, the_messages_menu[7], the_navibar[6]);
-	insert_action(ACT_NEXT_UNTRANSLATED, the_messages_menu[8], the_navibar[5]);
-	/*-----------------------------------------------------------*/
-	insert_action(ACT_TRANSLATED, the_msg_status_menu[0], NONE);
-	insert_action(ACT_FUZZY, the_msg_status_menu[1], NONE);
+	insert_action(ACT_FIRST, the_go_menu[0], the_navibar[0]);
+	insert_action(ACT_BACK, the_go_menu[1], the_navibar[1]);
+	insert_action(ACT_NEXT, the_go_menu[3], the_navibar[3]);
+	insert_action(ACT_LAST, the_go_menu[4], the_navibar[4]);
+	insert_action(ACT_GOTO, the_go_menu[6], the_navibar[7]);
+	insert_action(ACT_NEXT_FUZZY, the_go_menu[7], the_navibar[6]);
+	insert_action(ACT_NEXT_UNTRANSLATED, the_go_menu[8], the_navibar[5]);
 	/*-----------------------------------------------------------*/
 	insert_action(ACT_END, NONE, NONE);
 }
@@ -133,10 +131,10 @@ void gtranslator_actions_set_up_state_no_file(void)
 			ACT_FIND, ACT_FIND_AGAIN, ACT_HEADER, ACT_QUERY,
 			ACT_FIRST, ACT_BACK, ACT_NEXT, ACT_LAST, ACT_REPLACE,
 			ACT_GOTO, ACT_NEXT_FUZZY, ACT_NEXT_UNTRANSLATED,
-			ACT_FUZZY, ACT_TRANSLATED, ACT_COMMENT, ACT_EXPORT_UTF8,
+			ACT_FUZZY, ACT_COMMENT, ACT_EXPORT_UTF8,
 			ACT_REMOVE_ALL_TRANSLATIONS, ACT_COPY_MSGID2MSGSTR);
 
-	gtk_text_set_editable(GTK_TEXT(trans_box), FALSE);
+	gtk_text_view_set_editable(GTK_TEXT_VIEW(trans_box), FALSE);
 }
 
 void gtranslator_actions_set_up_file_opened(void)
@@ -144,7 +142,7 @@ void gtranslator_actions_set_up_file_opened(void)
 	gtranslator_actions_enable(ACT_COMPILE, ACT_SAVE_AS, ACT_CLOSE,
 		ACT_AUTOTRANSLATE, ACT_CUT, ACT_COPY, ACT_PASTE, ACT_CLEAR,
 		ACT_REPLACE, ACT_FIND, ACT_HEADER, ACT_NEXT, ACT_LAST,
-		ACT_QUERY, ACT_GOTO, ACT_FUZZY, ACT_TRANSLATED,
+		ACT_QUERY, ACT_GOTO, ACT_FUZZY,
 		ACT_IMPORT_UTF8, ACT_COPY_MSGID2MSGSTR);
 
 	gtranslator_actions_disable(ACT_SAVE, ACT_UNDO);
@@ -174,12 +172,12 @@ void gtranslator_actions_set_up_file_opened(void)
 	/*
 	 * Enable the editing of the msgstrs :-)
 	 */
-	gtk_text_set_editable(GTK_TEXT(trans_box), TRUE);
+	gtk_text_view_set_editable(GTK_TEXT_VIEW(trans_box), TRUE);
 
 	/*
 	 * Make it focused initially
 	 */
-	gtk_window_set_focus(GTK_WINDOW(gtranslator_application), trans_box);
+	gtk_window_set_focus(GTK_WINDOW(gtranslator_application), GTK_WIDGET(trans_box));
 }
 
 /*
@@ -203,12 +201,3 @@ void gtranslator_actions_undo(GtkWidget *widget, gpointer useless)
 	gtranslator_actions_disable(ACT_UNDO);
 }
 
-/*
- * Disable the corresponding menu item.
- */
-void gtranslator_actions_disable_fuzzy_menu_item(void)
-{
-	gtk_check_menu_item_set_active((GtkCheckMenuItem *) 
-		acts[ACT_FUZZY].menu, FALSE);
-}
-
