@@ -63,7 +63,6 @@ enum {
 	ACT_NEXT_FUZZY,
 	ACT_NEXT_UNTRANSLATED,
 	/***********************/
-	ACT_TRANSLATED,
 	ACT_FUZZY,
 	
 	/*
@@ -99,9 +98,4 @@ void gtranslator_actions_set_up_file_opened(void);
  */
 void gtranslator_actions_undo(GtkWidget *widget, gpointer useless);
 
-/*
- * A wrapper function for disabling the Fuzzy menu item.
- */
-void gtranslator_actions_disable_fuzzy_menu_item(void);
-
 #endif
