@@ -1,5 +1,5 @@
 /*
- * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,14 +36,10 @@
 
 #include <gtk/gtkmenushell.h>
 
-#include <gnome-xml/tree.h>
-#include <gnome-xml/parser.h>
+#include <libxml/tree.h>
+#include <libxml/parser.h>
 
-#ifdef ENABLE_NLS
 #include <libgnome/gnome-i18n.h>
-#endif
-
-#include <libgnome/gnome-util.h>
 
 #include <libgnomeui/gnome-app.h>
 #include <libgnomeui/gnome-app-helper.h>
@@ -190,7 +186,8 @@ GtrColorScheme *gtranslator_color_scheme_open(const gchar *filename)
  */
 void gtranslator_color_scheme_apply(const gchar *filename)
 {
-	GtrColorScheme *theme=g_new0(GtrColorScheme, 1);
+  /* GtrColorScheme*/
+        theme=g_new0(GtrColorScheme, 1);
 
 	theme=gtranslator_color_scheme_open(filename);
 
@@ -242,7 +239,7 @@ void gtranslator_color_scheme_apply(const gchar *filename)
 	gtranslator_config_set_string("scheme/filename", 
 		theme->info->filename);
 	
-	gtranslator_color_scheme_free(&theme);
+	//	gtranslator_color_scheme_free(&theme);
 }
 
 /*
@@ -250,7 +247,7 @@ void gtranslator_color_scheme_apply(const gchar *filename)
  */
 GtrColorScheme *gtranslator_color_scheme_load_from_prefs()
 {
-	GtrColorScheme *theme=g_new0(GtrColorScheme, 1);
+  /*GtrColorScheme */theme=g_new0(GtrColorScheme, 1);
 
 	theme->info=g_new0(GtrColorSchemeInformations, 1);
 
@@ -472,7 +469,7 @@ void gtranslator_color_scheme_show_list()
 
 	gint		 i=0;
 	
-	gchar 		*menupath=_("_Settings/_Colorschemes/");
+	gchar 		*menupath=_("_View/_Colorschemes/");
 
 	/*
 	 * Delete the old entries.
@@ -513,13 +510,13 @@ void gtranslator_color_scheme_show_list()
 		gnome_app_insert_menus(GNOME_APP(gtranslator_application), menupath, menu);
 		gnome_app_install_menu_hints(GNOME_APP(gtranslator_application), menu);
 
-		gtk_signal_connect(GTK_OBJECT(menu->widget), "destroy",
-			   GTK_SIGNAL_FUNC(free_data), menu->hint);
-
+		g_signal_connect(G_OBJECT(menu->widget), "destroy",
+			G_CALLBACK(free_data), (gpointer) menu->hint);
+		
 		/*
 		 * Free the string and the GnomeUIInfo structure.
 		 */
-		GTR_FREE(menu->label);
+ 		GTR_FREE((gpointer) menu->label);
 		GTR_FREE(menu);
 	}
 }
@@ -553,13 +550,13 @@ void apply_colorscheme(GtkWidget *widget, gchar *scheme_name)
 		 *  ~/.gtranslator/colorschemes directory, try the global 
 		 *   colorschemes directory.
 		 */
-		if(!g_file_exists(GtrPreferences.scheme))
+		if(!g_file_test(GtrPreferences.scheme, G_FILE_TEST_EXISTS))
 		{
 			GtrPreferences.scheme=g_strdup_printf("%s/%s.xml", 
 				SCHEMESDIR, scheme_name);
 		}
 
-		if(g_file_exists(GtrPreferences.scheme))
+		if(g_file_test(GtrPreferences.scheme, G_FILE_TEST_EXISTS))
 		{
 			/*
 			 * Free the old used colorscheme.
@@ -578,8 +575,8 @@ void apply_colorscheme(GtkWidget *widget, gchar *scheme_name)
 		GTR_FREE(scheme_name);
 	}
 
-	gtranslator_set_style(text_box, 0);
-        gtranslator_set_style(trans_box, 1);
+	gtranslator_set_style(GTK_WIDGET(text_box), 0);
+        gtranslator_set_style(GTK_WIDGET(trans_box), 1);
 }
 
 /*
