@@ -1,5 +1,5 @@
 /*
- * (C) 2000-2002 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
@@ -45,7 +45,6 @@
 
 #include <string.h>
 #include <locale.h>
-#include <libgnome/gnome-util.h>
 #include <libgnomeui/libgnomeui.h>
 
 /*
@@ -75,8 +74,8 @@ void gtranslator_dialog_show(GtkWidget ** dlg, const gchar * wmname)
 		gtk_window_set_wmclass(GTK_WINDOW(*dlg), wmname, "gtranslator");
 	if (GNOME_IS_DIALOG(*dlg))
 		gnome_dialog_set_parent(GNOME_DIALOG(*dlg), GTK_WINDOW(gtranslator_application));
-	gtk_signal_connect(GTK_OBJECT(*dlg), "destroy",
-			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), dlg);
+	g_signal_connect(G_OBJECT(*dlg), "destroy",
+			 G_CALLBACK(gtk_widget_destroyed), dlg);
 
 	gtk_widget_show_all(*dlg);
 }
@@ -93,17 +92,20 @@ void gtranslator_open_file_dialog(GtkWidget * widget, gpointer useless)
 		return;
 	}
 	
-	gtranslator_raise_dialog(dialog);
+	if(dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(dialog));
+		return;
+	}
 	dialog = gtk_file_selection_new(_("gtranslator -- open po file"));
 	
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
+	g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
 			   "clicked", GTK_SIGNAL_FUNC(gtranslator_parse_the_file_from_file_dialog),
 			   (gpointer) dialog);
-	gtk_signal_connect_object(GTK_OBJECT
-				  (GTK_FILE_SELECTION(dialog)->cancel_button),
-				  "clicked",
-				  GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				  GTK_OBJECT(dialog));
+	g_signal_connect_swapped(G_OBJECT
+				 (GTK_FILE_SELECTION(dialog)->cancel_button),
+				 "clicked",
+				 G_CALLBACK(gtk_widget_destroy),
+				 G_OBJECT(dialog));
 
 	gtranslator_file_dialogs_set_directory(&dialog);
 	
@@ -121,7 +123,10 @@ void gtranslator_open_file_dialog(GtkWidget * widget, gpointer useless)
 void gtranslator_save_file_as_dialog(GtkWidget * widget, gpointer useless)
 {
 	static GtkWidget *dialog = NULL;
-	gtranslator_raise_dialog(dialog);
+	if(dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(dialog));
+		return;
+	}
 
 	/*
 	 * If we do have write perms for the file we can save it under each
@@ -166,14 +171,14 @@ void gtranslator_save_file_as_dialog(GtkWidget * widget, gpointer useless)
 		GTR_FREE(filename);
 	}
 	
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
+	g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
 			   "clicked", GTK_SIGNAL_FUNC(gtranslator_save_file_dialog),
 			   (gpointer) dialog);
-	gtk_signal_connect_object(GTK_OBJECT
-				  (GTK_FILE_SELECTION(dialog)->cancel_button),
-				  "clicked",
-				  GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				  GTK_OBJECT(dialog));
+	g_signal_connect_swapped(G_OBJECT
+				 (GTK_FILE_SELECTION(dialog)->cancel_button),
+				 "clicked",
+				 G_CALLBACK(gtk_widget_destroy),
+				 G_OBJECT(dialog));
 
 	gtranslator_file_dialogs_set_directory(&dialog);
 	
@@ -233,14 +238,17 @@ void gtranslator_import_dialog(GtkWidget *widget, gpointer useless)
 		}
 	}
 
-	gtranslator_raise_dialog(import_dialog);
+	if(import_dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(import_dialog));
+		return;
+	}
 	import_dialog=gtk_file_selection_new(_("gtranslator -- import po file"));
 
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(import_dialog)->ok_button),
+	g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(import_dialog)->ok_button),
 		"clicked", GTK_SIGNAL_FUNC(gtranslator_import_dialog_clicked), (gpointer) import_dialog);
 
-	gtk_signal_connect_object(GTK_OBJECT(GTK_FILE_SELECTION(import_dialog)->cancel_button), 
-		"clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(import_dialog));
+	g_signal_connect_swapped(G_OBJECT(GTK_FILE_SELECTION(import_dialog)->cancel_button), 
+		"clicked", G_CALLBACK(gtk_widget_destroy), G_OBJECT(import_dialog));
 
 	gtranslator_file_dialogs_set_directory(&import_dialog);
 	
@@ -255,7 +263,7 @@ void gtranslator_import_dialog_clicked(GtkWidget *widget, gpointer dialog)
 {
 	gchar *filename;
 
-	filename=gtk_file_selection_get_filename(GTK_FILE_SELECTION(dialog));
+	filename=g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(dialog)));
 	gtranslator_file_dialogs_store_directory(filename);
 
 	/*
@@ -275,15 +283,18 @@ void gtranslator_export_dialog(GtkWidget *widget, gpointer useless)
 	static GtkWidget *export_dialog=NULL;
 	
 	g_return_if_fail(file_opened==TRUE);
-	gtranslator_raise_dialog(export_dialog);
+	if(export_dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(export_dialog));
+		return;
+	}
 
 	export_dialog=gtk_file_selection_new(_("gtranslator -- export po file"));
 
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(export_dialog)->ok_button),
+	g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(export_dialog)->ok_button),
 		"clicked", GTK_SIGNAL_FUNC(gtranslator_export_dialog_clicked), (gpointer) export_dialog);
 
-	gtk_signal_connect_object(GTK_OBJECT(GTK_FILE_SELECTION(export_dialog)->cancel_button), 
-		"clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(export_dialog));
+	g_signal_connect_swapped(G_OBJECT(GTK_FILE_SELECTION(export_dialog)->cancel_button), 
+		"clicked", G_CALLBACK(gtk_widget_destroy), G_OBJECT(export_dialog));
 
 	gtranslator_file_dialogs_set_directory(&export_dialog);
 
@@ -298,7 +309,7 @@ void gtranslator_export_dialog_clicked(GtkWidget *widget, gpointer dialog)
 {
 	gchar *filename;
 
-	filename=gtk_file_selection_get_filename(GTK_FILE_SELECTION(dialog));
+	filename=g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(dialog)));
 	gtranslator_file_dialogs_store_directory(filename);
 
 	/*
@@ -529,14 +540,14 @@ void gtranslator_file_dialogs_set_directory(GtkWidget **fileselection)
 	{
 		directory=gtranslator_config_get_string("informations/last_directory");
 
-		if(directory && g_file_test(directory, G_FILE_TEST_ISDIR))
+		if(directory && g_file_test(directory, G_FILE_TEST_IS_DIR))
 		{
 			gtk_file_selection_complete(
 				GTK_FILE_SELECTION(*fileselection), directory);
 		}
 		else
 		{
-			directory=g_get_home_dir();
+			directory=g_strdup(g_get_home_dir());
 			gtk_file_selection_complete(
 				GTK_FILE_SELECTION(*fileselection), directory);
 		}
@@ -590,7 +601,10 @@ void gtranslator_go_to_dialog(GtkWidget * widget, gpointer useless)
 		gtk_adjustment_set_value(GTK_ADJUSTMENT(adjustment),
 					 g_list_position(po->messages,
 							 po->current) + 1);
-	gtranslator_raise_dialog(dialog);
+	if(dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(dialog));
+		return;
+	}
 	dialog = gnome_dialog_new(_("gtranslator -- go to"), NULL);
 	gnome_dialog_append_button_with_pixmap (GNOME_DIALOG (dialog),
 						_("Go!"),
@@ -623,8 +637,8 @@ void gtranslator_go_to_dialog(GtkWidget * widget, gpointer useless)
 	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), spin,
 			   FALSE, FALSE, 0);
 	
-	gtk_signal_connect(GTK_OBJECT(dialog), "clicked",
-			   GTK_SIGNAL_FUNC(gtranslator_go_to_dialog_clicked),
+	g_signal_connect(G_OBJECT(dialog), "clicked",
+			 G_CALLBACK(gtranslator_go_to_dialog_clicked),
 			   spin);
 	gtk_window_set_focus(GTK_WINDOW(dialog), spin);
 	gtranslator_dialog_show(&dialog, "gtranslator -- goto");
@@ -667,7 +681,10 @@ void gtranslator_find_dialog(GtkWidget * widget, gpointer useless)
 	GtkWidget *label, *findy, *match_case;
 	GtkWidget *find_in, *menu, *menu_item, *option, *hbox;
 
-	gtranslator_raise_dialog(dialog);
+	if(dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(dialog));
+		return;
+	}
 	dialog = gnome_dialog_new(_("Find in the po file"), NULL);
 	gnome_dialog_append_button_with_pixmap (GNOME_DIALOG (dialog),
 						_("Find"),
@@ -688,33 +705,33 @@ void gtranslator_find_dialog(GtkWidget * widget, gpointer useless)
 
 	menu = gtk_menu_new();
 	menu_item = gtk_menu_item_new_with_label(_("English"));
-	gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
-			   GTK_SIGNAL_FUNC(find_in_activated),
+	g_signal_connect(G_OBJECT(menu_item), "activate",
+			 G_CALLBACK(find_in_activated),
 			   GINT_TO_POINTER(findEnglish));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
 	
 	menu_item = gtk_menu_item_new_with_label(_("Translated"));
-	gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
-			   GTK_SIGNAL_FUNC(find_in_activated),
+	g_signal_connect(G_OBJECT(menu_item), "activate",
+			 G_CALLBACK(find_in_activated),
 			   GINT_TO_POINTER(findTranslated));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
 	
 	menu_item = gtk_menu_item_new_with_label(_("Both"));
-	gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
-			   GTK_SIGNAL_FUNC(find_in_activated),
-			   GINT_TO_POINTER(findBoth));
+	g_signal_connect(G_OBJECT(menu_item), "activate",
+			 G_CALLBACK(find_in_activated),
+			 GINT_TO_POINTER(findBoth));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
 	
 	menu_item = gtk_menu_item_new_with_label(_("Comments"));
-	gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
-			   GTK_SIGNAL_FUNC(find_in_activated),
-			   GINT_TO_POINTER(findComment));
+	g_signal_connect(G_OBJECT(menu_item), "activate",
+			 G_CALLBACK(find_in_activated),
+			 GINT_TO_POINTER(findComment));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
 	
 	menu_item = gtk_menu_item_new_with_label(_("In all strings"));
-	gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
-			   GTK_SIGNAL_FUNC(find_in_activated),
-			   GINT_TO_POINTER(findAll));
+	g_signal_connect(G_OBJECT(menu_item), "activate",
+			 G_CALLBACK(find_in_activated),
+			 GINT_TO_POINTER(findAll));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
 	
 	switch (GtrPreferences.find_in) {
@@ -748,10 +765,10 @@ void gtranslator_find_dialog(GtkWidget * widget, gpointer useless)
 	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), hbox,
 			   FALSE, FALSE, 0);
 	
-	gtk_signal_connect(GTK_OBJECT(dialog), "clicked",
-			   GTK_SIGNAL_FUNC(find_dlg_clicked), findy);
-	gtk_signal_connect(GTK_OBJECT(match_case), "toggled",
-			   GTK_SIGNAL_FUNC(match_case_toggled), NULL);
+	g_signal_connect(G_OBJECT(dialog), "clicked",
+			 G_CALLBACK(find_dlg_clicked), findy);
+	g_signal_connect(G_OBJECT(match_case), "toggled",
+			 G_CALLBACK(match_case_toggled), NULL);
 	gtk_window_set_focus(GTK_WINDOW(dialog), 
 		gnome_entry_gtk_entry(GNOME_ENTRY(findy)));
 	
@@ -770,7 +787,10 @@ void gtranslator_replace_dialog(GtkWidget *widget, gpointer useless)
 	GtkWidget *findy, *replacy;
 	GtkWidget *find_in, *menu, *menu_item, *option, *hbox;
 
-	gtranslator_raise_dialog(dialog);
+	if(dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(dialog));
+		return;
+	}
 	dialog=gnome_dialog_new(_("gtranslator -- replace"),
 		_("Replace"),
 		_("Replace all"),
@@ -786,19 +806,19 @@ void gtranslator_replace_dialog(GtkWidget *widget, gpointer useless)
 	menu=gtk_menu_new();
 	
 	menu_item = gtk_menu_item_new_with_label(_("Comments"));
-	gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
+	g_signal_connect(G_OBJECT(menu_item), "activate",
 		GTK_SIGNAL_FUNC(find_in_activated),
 		GINT_TO_POINTER(findComment));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
 
 	menu_item=gtk_menu_item_new_with_label(_("Translated"));
-	gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
+	g_signal_connect(G_OBJECT(menu_item), "activate",
 		GTK_SIGNAL_FUNC(find_in_activated),
 		GINT_TO_POINTER(findTranslated));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
 	
 	menu_item=gtk_menu_item_new_with_label(_("Both"));
-	gtk_signal_connect(GTK_OBJECT(menu_item), "activate",
+	g_signal_connect(G_OBJECT(menu_item), "activate",
 		GTK_SIGNAL_FUNC(find_in_activated),
 		GINT_TO_POINTER(findBoth));
 	gtk_menu_append(GTK_MENU(menu), menu_item);
@@ -900,7 +920,7 @@ void gtranslator_compile_error_dialog(FILE * fs)
 
 	dialog = gtranslator_utils_error_dialog(_("An error occurred while msgfmt was executed:\n"));
 	textbox = gtk_text_new(NULL, NULL);
-	gtk_text_set_editable(GTK_TEXT(textbox), FALSE);
+	//	gtk_text_set_editable(GTK_TEXT(textbox), FALSE);
 	while (TRUE) {
 		len = fread(buf, 1, sizeof(buf), fs);
 		if (len == 0)
@@ -926,7 +946,10 @@ void gtranslator_open_uri_dialog(GtkWidget *widget, gpointer useless)
 	GtkWidget *entry;
 	GtkWidget *label;
 
-	gtranslator_raise_dialog(dialog);
+	if(dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(dialog));
+		return;
+	}
 
 	dialog=gnome_dialog_new(_("gtranslator -- open from URI"),
 				_("Open"), GNOME_STOCK_BUTTON_CANCEL, 
@@ -949,7 +972,7 @@ void gtranslator_open_uri_dialog(GtkWidget *widget, gpointer useless)
 	gnome_dialog_editable_enters(GNOME_DIALOG(dialog),
 		GTK_EDITABLE(gnome_entry_gtk_entry(GNOME_ENTRY(entry))));
 
-	gtk_signal_connect(GTK_OBJECT(dialog), "clicked",
+	g_signal_connect(G_OBJECT(dialog), "clicked",
 		GTK_SIGNAL_FUNC(gtranslator_open_uri_dialog_clicked), entry);
 			
 	gtranslator_dialog_show(&dialog, "gtranslator -- open URI");
@@ -1092,7 +1115,10 @@ void gtranslator_query_dialog(void)
 
 	gint reply;
 	
-	gtranslator_raise_dialog(dialog);
+	if(dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(dialog));
+		return;
+	}
 
 	#define add2Box(x); \
 	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), x, \
@@ -1242,8 +1268,7 @@ Would you like to insert it into the translation?"),
 						 * Insert the text and update the
 						 * status flags for it.
 						 */
-						gtk_text_insert(GTK_TEXT(trans_box), NULL, NULL, NULL,
-							result, strlen(result));
+					        gtk_text_buffer_set_text(gtk_text_view_get_buffer(trans_box), result, -1);
 
 						gtranslator_translation_changed(NULL, NULL);
 
@@ -1282,7 +1307,10 @@ void gtranslator_auto_translation_dialog(void)
     	gchar 	*message_string=NULL;
 	gint 		reply;
 
-	gtranslator_raise_dialog(dialog);
+	if(dialog != NULL) {
+		gtk_window_present(GTK_WINDOW(dialog));
+		return;
+	}
 
 	message_string=_("Should gtranslator autotranslate the file using information\n\
 from your personal learn buffer?");
