@@ -1,7 +1,8 @@
 /*
- * (C) 2000-2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  *			Peeter Vois <peeter@gtranslator.org>
+ *			Thomas Ziehmer <thomas@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +26,6 @@
 
 #include "about.h"
 #include "actions.h"
-#include "backend.h"
 #include "color-schemes.h"
 #include "dialogs.h"
 #include "dnd.h"
@@ -65,19 +65,13 @@
 
 #include <libgnomevfs/gnome-vfs-init.h>
 
-#include <gal/e-paned/e-hpaned.h>
-#include <gal/e-paned/e-vpaned.h>
-
-#include <gal/e-table/e-table.h>
-#include <gal/e-table/e-table-scrolled.h>
-
 /*
  * Global external variables
  */
 GtkWidget *gtranslator_application;
 GtkWidget *gtranslator_messages_table;
-GtkWidget *trans_box;
-GtkWidget *text_box;
+GtkTextView *trans_box;
+GtkTextView *text_box;
 GtkWidget *gtranslator_application_bar;
 
 GtkWidget *content_pane;
@@ -90,20 +84,15 @@ GtrExtraContentArea *extra_content_view;
 
 gboolean nothing_changes;
 
-/*
- * Popup menu creation/deletion functions.
- */
-static gint create_popup_menu(GtkText *widget, GdkEventButton *event, 
-	gpointer d);
-
 /*
  * Internal text callbacks/handlers.
  */
-void insert_text_handler (GtkEditable *editable, const gchar *text,
-	gint length, gint *position, gpointer data);
+static void insert_text_handler (GtkTextBuffer *editable, GtkTextIter *pos,
+				 const gchar *text,
+				 gint length, gpointer data);
 
-void delete_text_handler(GtkEditable *editable, gint start_position,
-	gint end_position);
+static void delete_text_handler(GtkTextBuffer *textbuf, GtkTextIter *start,
+				GtkTextIter *end);
 
 static void selection_get_handler(GtkWidget *widget,
 	GtkSelectionData *selection_data, guint info,
@@ -132,35 +121,6 @@ static  GtkTargetEntry dragtypes[] = {
  */
 static gint	table_pane_position;
 
-/*
- * Pop's up the curious popup-menu.
- */
-static gint create_popup_menu(GtkText *widget, GdkEventButton *event, gpointer d)
-{
-	/*
-	 * Only react on rightclick.
-	 */
-	if(event->button==3)
-	{
-		/*
-		 * Only respond if a file has been present/opened and if the
-		 * corresponding option is set.
-		 */
-		if((GtrPreferences.popup_menu) && (file_opened==TRUE))
-		{
-			GtkWidget *popup_menu;
-
-			popup_menu=gnome_popup_menu_new(the_main_popup_menu);
-
-			gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL,
-				NULL, NULL, event->button, event->time);
-
-			return TRUE;
-		}
-	}
-	return FALSE;
-}
-
 /*
  * Creates the main gtranslator window.
  */
@@ -176,6 +136,7 @@ void gtranslator_create_main_window(void)
 	GtkWidget *comments_scrolled_window;
 	GtkWidget *comments_viewport;
 
+	GtkWidget *messages_table_scrolled_window;
 	/*
 	 * Create the app	
 	 */
@@ -185,8 +146,8 @@ void gtranslator_create_main_window(void)
 	/*
 	 * Create all the panes we're using later on.
 	 */
-	content_pane=e_vpaned_new();
-	table_pane=e_hpaned_new();
+	content_pane=gtk_vpaned_new();
+	table_pane=gtk_hpaned_new();
 	
 
 	if(GtrPreferences.show_messages_table)
@@ -206,11 +167,11 @@ void gtranslator_create_main_window(void)
 		table_pane_position=gtranslator_config_get_int(
 			"interface/table_pane_position");
 
-		e_paned_set_position(E_PANED(table_pane), table_pane_position);
+		gtk_paned_set_position(GTK_PANED(table_pane), table_pane_position);
 	}
 	else
 	{
-		e_paned_set_position(E_PANED(table_pane), -1);
+		gtk_paned_set_position(GTK_PANED(table_pane), -1);
 	}
 	
 	extra_content_view=g_new0(GtrExtraContentArea, 1);
@@ -235,50 +196,54 @@ void gtranslator_create_main_window(void)
 	gtk_box_pack_end(GTK_BOX(extra_content_view->box), extra_content_view->edit_button,
 		FALSE, FALSE, 0);
 	
-	e_paned_set_position(E_PANED(content_pane), 0);
+	gtk_paned_set_position(GTK_PANED(content_pane), 0);
 
 	/*
 	 * Create the tool- and search-bar
 	 */
-	tool_bar =
-	    gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_BOTH);
+	tool_bar = gtk_toolbar_new();
 	gnome_app_fill_toolbar(GTK_TOOLBAR(tool_bar), the_toolbar, NULL);
 	gnome_app_add_toolbar(GNOME_APP(gtranslator_application), GTK_TOOLBAR(tool_bar),
-			      "tool_bar", GNOME_DOCK_ITEM_BEH_EXCLUSIVE,
-			      GNOME_DOCK_TOP, 1, 0, 0);
+			      "tool_bar", BONOBO_DOCK_ITEM_BEH_EXCLUSIVE,
+			      BONOBO_DOCK_TOP, 1, 0, 0);
 
-	search_bar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL,
-				     GTK_TOOLBAR_BOTH);
+	search_bar = gtk_toolbar_new();
 	gnome_app_fill_toolbar(GTK_TOOLBAR(search_bar), the_navibar, NULL);
 	gnome_app_add_toolbar(GNOME_APP(gtranslator_application), 
 		GTK_TOOLBAR(search_bar),
-		"search_bar", GNOME_DOCK_ITEM_BEH_EXCLUSIVE,
-		GNOME_DOCK_TOP, 2, 0, 0);
+		"search_bar", BONOBO_DOCK_ITEM_BEH_EXCLUSIVE,
+		BONOBO_DOCK_TOP, 2, 0, 0);
 
 	vertical_box=gtk_vbox_new(FALSE, 0);
 
 	/*
 	 * Perform all the packing action between the EPaneds.
 	 */
-	e_paned_pack1(E_PANED(content_pane), extra_content_view->box, TRUE, FALSE);
-	e_paned_pack2(E_PANED(content_pane), vertical_box, TRUE, FALSE);
+	gtk_paned_pack1(GTK_PANED(content_pane), extra_content_view->box, 
+			TRUE, FALSE);
+	gtk_paned_pack2(GTK_PANED(content_pane), vertical_box, FALSE, TRUE);
 
-	e_paned_pack1(E_PANED(table_pane), gtranslator_messages_table, TRUE, FALSE);
-	e_paned_pack2(E_PANED(table_pane), content_pane, TRUE, FALSE);
+	messages_table_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+	gtk_container_add(GTK_CONTAINER(messages_table_scrolled_window), gtranslator_messages_table);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(messages_table_scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_paned_pack1(GTK_PANED(table_pane), messages_table_scrolled_window, FALSE, TRUE);
+	gtk_paned_pack2(GTK_PANED(table_pane), content_pane, FALSE, TRUE);
 	
 	gnome_app_set_contents(GNOME_APP(gtranslator_application), table_pane);
 
 	original_text_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_box_pack_start(GTK_BOX(vertical_box), original_text_scrolled_window, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vertical_box), gtk_hseparator_new(), FALSE, TRUE, 0);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(original_text_scrolled_window),
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
 
-	text_box=gtk_text_new(NULL,NULL);
-	
-	gtk_container_add(GTK_CONTAINER(original_text_scrolled_window), text_box);
-	
-	gtk_text_set_editable(GTK_TEXT(text_box), FALSE);
+	text_box = GTK_TEXT_VIEW(gtk_text_view_new ());
+	gtk_text_view_set_editable(text_box, FALSE);
+	gtk_text_view_set_wrap_mode(text_box, GTK_WRAP_CHAR);
+	gtk_text_view_set_cursor_visible(text_box, FALSE);
+
+	gtk_container_add(GTK_CONTAINER(original_text_scrolled_window), GTK_WIDGET(text_box));
 
 	translation_text_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_box_pack_start(GTK_BOX(vertical_box), translation_text_scrolled_window, TRUE, TRUE, 0);
@@ -286,8 +251,12 @@ void gtranslator_create_main_window(void)
 				       GTK_POLICY_NEVER,
 				       GTK_POLICY_AUTOMATIC);
 
-	trans_box = gtk_text_new(NULL, NULL);
-	gtk_container_add(GTK_CONTAINER(translation_text_scrolled_window), trans_box);
+	trans_box = GTK_TEXT_VIEW(gtk_text_view_new());
+	gtk_text_view_set_editable(trans_box, TRUE);
+	gtk_text_view_set_wrap_mode(trans_box, GTK_WRAP_CHAR);
+	gtk_text_view_set_cursor_visible(trans_box, TRUE);
+
+	gtk_container_add(GTK_CONTAINER(translation_text_scrolled_window), GTK_WIDGET(trans_box));
 
 	gtranslator_application_bar = gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_NEVER);
 	gnome_app_set_statusbar(GNOME_APP(gtranslator_application), gtranslator_application_bar);
@@ -305,48 +274,50 @@ void gtranslator_create_main_window(void)
 	/*
 	 * Set up our special styles for the text boxes.
 	 */
-	gtranslator_set_style(text_box, 0);
-	gtranslator_set_style(trans_box, 1);
+	//	gtranslator_set_style(GTK_WIDGET(text_box), 0);
+	//gtranslator_set_style(GTK_WIDGET(trans_box), 1);
 	/*
 	 *  Initialize highlighting
 	 */
-	 gtranslator_syntax_init(GTK_EDITABLE(trans_box));
-	 gtranslator_syntax_init(GTK_EDITABLE(text_box));
+	 gtranslator_syntax_init(trans_box);
+	 gtranslator_syntax_init(text_box);
 	/*
 	 * The callbacks list
 	 */
-	gtk_signal_connect(GTK_OBJECT(gtranslator_application), "delete_event",
-			   GTK_SIGNAL_FUNC(gtranslator_quit), NULL);
+	g_signal_connect(G_OBJECT(gtranslator_application), "delete_event",
+			 G_CALLBACK(gtranslator_quit), NULL);
 
-	gtk_signal_connect(GTK_OBJECT(extra_content_view->edit_button), "clicked",
-			   GTK_SIGNAL_FUNC(gtranslator_edit_comment_dialog), NULL);
+	g_signal_connect(G_OBJECT(extra_content_view->edit_button), "clicked",
+			 G_CALLBACK(gtranslator_edit_comment_dialog), NULL);
 
-	gtk_signal_connect_after(GTK_OBJECT(text_box), "selection_get",
-			   GTK_SIGNAL_FUNC(selection_get_handler), NULL);
-	gtk_signal_connect_after(GTK_OBJECT(trans_box), "selection_get",
-			   GTK_SIGNAL_FUNC(selection_get_handler), NULL);
+	g_signal_connect_after(G_OBJECT(text_box), "selection-get",
+			 G_CALLBACK(selection_get_handler), NULL);
+	g_signal_connect_after(G_OBJECT(trans_box), "selection-get",
+			 G_CALLBACK(selection_get_handler), NULL);
+/*
+	g_signal_connect(G_OBJECT(gtk_text_view_get_buffer(text_box)), 
+			 "insert-text",
+			 G_CALLBACK(insert_text_handler), NULL);
+	g_signal_connect(G_OBJECT(gtk_text_view_get_buffer(text_box)),
+			 "delete-range",
+			 G_CALLBACK(delete_text_handler), NULL);
+*/
 
-	gtk_signal_connect(GTK_OBJECT(text_box), "insert_text",
-			   GTK_SIGNAL_FUNC(insert_text_handler), NULL);
-	gtk_signal_connect(GTK_OBJECT(text_box), "delete_text",
-			   GTK_SIGNAL_FUNC(delete_text_handler), NULL);
+/*	g_signal_connect(G_OBJECT(gtk_text_view_get_buffer(trans_box)), 
+			 "insert-text",
+			 G_CALLBACK(insert_text_handler), NULL);
 
-
-	gtk_signal_connect(GTK_OBJECT(trans_box), "insert_text",
-			   GTK_SIGNAL_FUNC(insert_text_handler), NULL);
-	gtk_signal_connect(GTK_OBJECT(trans_box), "delete_text",
-			   GTK_SIGNAL_FUNC(delete_text_handler), NULL);
+	g_signal_connect(G_OBJECT(gtk_text_view_get_buffer(trans_box)), 
+			 "delete-range",
+			 G_CALLBACK(delete_text_handler), NULL);
+*/
 	
-	gtk_signal_connect(GTK_OBJECT(trans_box), "changed",
-			   GTK_SIGNAL_FUNC(gtranslator_translation_changed), NULL);
+	g_signal_connect(G_OBJECT(gtk_text_view_get_buffer(trans_box)), 
+			 "changed",
+			 G_CALLBACK(gtranslator_translation_changed), NULL);
 	
-	gtk_signal_connect(GTK_OBJECT(text_box), "button_press_event",
-			   GTK_SIGNAL_FUNC(create_popup_menu), NULL);
-	gtk_signal_connect(GTK_OBJECT(trans_box), "button_press_event",
-			   GTK_SIGNAL_FUNC(create_popup_menu), NULL);
-	
-	gtk_signal_connect(GTK_OBJECT(gtranslator_application), "key_press_event",
-			   GTK_SIGNAL_FUNC(gtranslator_keyhandler), NULL);
+	g_signal_connect(G_OBJECT(gtranslator_application), "key-press-event",
+			 G_CALLBACK(gtranslator_keyhandler), NULL);
 	/*
 	 * The D'n'D signals
 	 */
@@ -354,38 +325,37 @@ void gtranslator_create_main_window(void)
 			  GTK_DEST_DEFAULT_ALL | GTK_DEST_DEFAULT_HIGHLIGHT,
 			  dragtypes, sizeof(dragtypes) / sizeof(dragtypes[0]),
 			  GDK_ACTION_COPY);
-	gtk_signal_connect(GTK_OBJECT(gtranslator_application), "drag_data_received",
-			   GTK_SIGNAL_FUNC(gtranslator_dnd),
-			   GUINT_TO_POINTER(dnd_type));
+	g_signal_connect(G_OBJECT(gtranslator_application), "drag-data-received",
+			 G_CALLBACK(gtranslator_dnd),
+			 GUINT_TO_POINTER(dnd_type));
 }
 
 /*
  * An own delete text handler which should work on deletion in the translation
  *  box -- undo is called up here, too.
  */
-void delete_text_handler(GtkEditable *editable, gint start_position,
-	gint end_position)
+void delete_text_handler(GtkTextBuffer *textbuf, GtkTextIter *start,
+			 GtkTextIter *end)
 {
+	return;
 	/*
 	 * Check for dumb values and do only catch real deletions.
 	 */
-	if(start_position >= 0 && end_position >= 1 && 
-		(end_position > start_position))
+	if(gtk_text_iter_compare(start, end)>=0)
 	{
 		gchar	*fake_string;
 
 		/*
 		 * Fill up our fake_string for the strlen() call in undo.c.
 		 */
-		fake_string=gtk_editable_get_chars(GTK_EDITABLE(trans_box),
-			start_position, (end_position - start_position));
+		fake_string=gtk_text_buffer_get_text(textbuf, 
+						     start, end, FALSE);
 		
-		gtranslator_undo_register_deletion(fake_string, start_position);
+//		gtranslator_undo_register_deletion(fake_string, start_position);
 		GTR_FREE(fake_string);
 	}
-//	gtranslator_delete_highlighted(editable, 
-//			start_position, end_position - start_position);
-//	gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "delete_text");
+	gtranslator_delete_highlighted(textbuf, start, end, NULL);
+	g_signal_stop_emission_by_name (G_OBJECT (textbuf), "delete_text");
 }
 
 /*
@@ -405,7 +375,7 @@ gint gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
 	/*
 	 * Get the EPaned's position offset.
 	 */
-	table_pane_position=e_paned_get_position(E_PANED(table_pane));
+	table_pane_position=gtk_paned_get_position(GTK_PANED(table_pane));
 	
 	/*
 	 * Store the pane position in the preferences.
@@ -426,11 +396,6 @@ gint gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
 		gtranslator_messages_table_save_state();
 	}
 
-	/*
-	 * Also clean up/free our backend space.
-	 */
-	gtranslator_backend_remove_all_backends();
-
 	/*
 	 * Shutdown our internal learning system.
 	 */
@@ -500,8 +465,16 @@ gint gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
  */
 void gtranslator_text_boxes_clean()
 {
-	gtk_editable_delete_text(GTK_EDITABLE(text_box), 0, -1);
-	gtk_editable_delete_text(GTK_EDITABLE(trans_box), 0, -1);
+	GtkTextIter start, end;
+	GtkTextBuffer *buffer;
+
+	buffer = GTK_TEXT_BUFFER(gtk_text_view_get_buffer(text_box));
+	gtk_text_buffer_get_bounds(buffer, &start, &end);
+	gtk_text_buffer_delete(buffer, &start, &end);
+
+	buffer = GTK_TEXT_BUFFER(gtk_text_view_get_buffer(trans_box));
+	gtk_text_buffer_get_bounds(buffer, &start, &end);
+	gtk_text_buffer_delete(buffer, &start, &end);
 }
 
 void gtranslator_application_bar_update(gint pos)
@@ -601,14 +574,15 @@ void gtranslator_clipboard_paste(GtkWidget  * widget, gpointer useless)
 
 void gtranslator_selection_clear(GtkWidget  * widget, gpointer useless)
 {
-	gtk_editable_delete_selection(GTK_EDITABLE(trans_box));
+	GtkTextBuffer *buffer = GTK_TEXT_BUFFER(gtk_text_view_get_buffer(trans_box));
+	gtk_text_buffer_delete_selection(buffer, TRUE, TRUE);
 }
 
 /*
  * Set po->file_changed to TRUE if the text in the translation box has been
  * updated.
  */
-void gtranslator_translation_changed(GtkWidget  * widget, gpointer useless)
+void gtranslator_translation_changed(GtkWidget  *buffer, gpointer useless)
 {
 	if (nothing_changes)
 		return;
@@ -633,7 +607,10 @@ void gtranslator_translation_changed(GtkWidget  * widget, gpointer useless)
 		     && (msg->status & GTR_MSG_STATUS_FUZZY))
 		{
 		     	gtranslator_message_status_set_fuzzy(msg, FALSE);
-			gtranslator_actions_disable_fuzzy_menu_item();
+			gtk_check_menu_item_set_active(
+				GTK_CHECK_MENU_ITEM(the_edit_menu[19].widget),
+				FALSE
+			);
 		}
 		if(GtrPreferences.show_messages_table)
 		{
@@ -645,43 +622,49 @@ void gtranslator_translation_changed(GtkWidget  * widget, gpointer useless)
 /*
  * When inserting text, exchange spaces with dot chars 
  */
-void insert_text_handler (GtkEditable *editable, const gchar *text,
-			  gint length, gint *position, gpointer data)
+void insert_text_handler (GtkTextBuffer *textbuffer, GtkTextIter *pos,
+			  const gchar *text,
+			  gint length, gpointer data)
 {
-//	gchar *result;
+	gchar *result;
 
-//	result=g_strdup(text);
+	result=g_strdup(text);
 	if (!nothing_changes)
 	{
 		/*
 		* Register the text for an insertion undo action.
 		*/
-		gtranslator_undo_register_insertion(text, *position);
+//		gtranslator_undo_register_insertion(text, *position);
 
 		if(GtrPreferences.dot_char)
 		{
-			gtranslator_utils_invert_dot((gchar*)text);
+			gchar *old;
+			old = result;
+			result = gtranslator_utils_invert_dot((gchar*)result);
+			g_free(old);
 		}
 	}
-//	gtranslator_insert_highlighted(editable, result, position, length);
-//	g_free(result);
-//	gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
-//	gtk_editable_set_position(GTK_EDITABLE(editable), *position);
+	gtranslator_insert_highlighted(textbuffer, pos, result, length, NULL);
+	g_free(result);
+	g_signal_stop_emission_by_name (G_OBJECT(textbuffer), "insert_text");
+	gtk_text_buffer_place_cursor(textbuffer, pos);
 }
 
 void selection_get_handler(GtkWidget *widget, GtkSelectionData *selection_data,
 			   guint info, guint time_stamp, gpointer data)
 {
 	gchar *text;
+	gchar *undotted_text;
 
 	if(!GtrPreferences.dot_char)
 		return;
 
 	text = g_strndup(selection_data->data, selection_data->length);
-	gtranslator_utils_invert_dot(text);
+	undotted_text = gtranslator_utils_invert_dot(text);
 	gtk_selection_data_set(selection_data, selection_data->type,
-			       8, text, strlen(text));
+			       8, undotted_text, strlen(text));
 	g_free(text);
+	g_free(undotted_text);
 }
 
 /*
@@ -702,7 +685,7 @@ static gint gtranslator_keyhandler(GtkWidget *widget, GdkEventKey *event)
 		 */
 		if(event->state & GDK_SHIFT_MASK)
 		{
-			return TRUE;
+			return FALSE;
 		}
 
 		/*
@@ -749,5 +732,5 @@ static gint gtranslator_keyhandler(GtkWidget *widget, GdkEventKey *event)
 		}
 	}
 	
-	return TRUE;
+	return FALSE;
 }
