@@ -25,7 +25,8 @@
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkeditable.h>
 
-#include <libgnome/gnome-defs.h>
+#include <libgnomeui/libgnomeui.h>
+//#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 
 /*
@@ -33,8 +34,8 @@
  */
 extern GtkWidget *gtranslator_application;
 extern GtkWidget *gtranslator_messages_table;
-extern GtkWidget *trans_box;
-extern GtkWidget *text_box;
+extern GtkTextView *trans_box;
+extern GtkTextView *text_box;
 extern GtkWidget *gtranslator_application_bar;
 
 extern GtkWidget *sidebar_pane;
@@ -85,12 +86,6 @@ void gtranslator_selection_clear(GtkWidget  *widget, gpointer useless);
  */
 void gtranslator_translation_changed(GtkWidget  *widget, gpointer useless);
 
-void insert_text_handler(GtkEditable *editable, const gchar *text,
-			 gint length, gint *position, gpointer data);
-
-void delete_text_handler(GtkEditable *editable, gint start_position,
-                         gint end_position);
-
 /*
  * If TRUE, means that trans_box is being changed by program, not user
  */
