@@ -32,7 +32,6 @@
 #include "parse.h"
 #include "prefs.h"
 #include "translator.h"
-#include "utf8.h"
 #include "utils.h"
 #include "utils_gui.h"
 
@@ -93,11 +92,11 @@ GtrHeader * gtranslator_header_get(GtrMsg * msg)
 		return NULL;
 	
 	ph = g_new0(GtrHeader, 1);
-	lines = g_strsplit(msg->msgstr, "\n", 0);
+	lines = g_strsplit(msg->msgstr, "\\n", 0);
 	while (lines[i] != NULL) {
 		pair = g_strsplit(lines[i], ": ", 2);
 
-#define if_key_is(str) if (!g_strcasecmp(pair[0],str))
+#define if_key_is(str) if (pair[0] && !g_strcasecmp(pair[0],str))
 		if_key_is("Project-Id-Version") {
 			gchar *space;
 			space = strrchr (pair[1], ' ');
@@ -278,6 +277,8 @@ static void gtranslator_header_edit_apply(GtkWidget * box, gint page_num, gpoint
 	GtrHeader 	*ph = po->header;
 	gchar		*prev_translator,
 			*prev_translator_email;
+	GtkTextBuffer   *buff;
+	GtkTextIter     start, end;
 
 	prev_translator=prev_translator_email=NULL;
 
@@ -288,30 +289,23 @@ static void gtranslator_header_edit_apply(GtkWidget * box, gint page_num, gpoint
 	value = gtk_editable_get_chars(GTK_EDITABLE(widget),0,-1);
 	update(ph->prj_name, prj_name);
 	update(ph->prj_version, prj_version);
-	update(ph->comment, prj_comment);
+
+	buff = gtk_text_view_get_buffer(GTK_TEXT_VIEW(prj_comment));
+	gtk_text_buffer_get_start_iter(buff, &start);
+	gtk_text_buffer_get_start_iter(buff, &end);
+	GTR_FREE(ph->comment);
+	ph->comment = gtk_text_buffer_get_text(buff, &start, &end, FALSE);
 
 	if (!GtrPreferences.fill_header) {
 		
-		if(po->utf8)
+		if(ph->translator)
 		{
-			if(ph->translator)
-			{
-				prev_translator=g_strdup(ph->translator);
-				GTR_FREE(ph->translator);
-			}
-			
-			ph->translator=gtranslator_utf8_get_gtk_entry_as_utf8_string(translator);
-		}
-		else
-		{
-			if(ph->translator)
-			{
-				prev_translator=g_strdup(ph->translator);
-			}
-			
-			update(ph->translator, translator);
+			prev_translator=g_strdup(ph->translator);
+			GTR_FREE(ph->translator);
 		}
 		
+		ph->translator = gtk_editable_get_chars(GTK_EDITABLE(translator),0,-1);
+		
 		if(ph->tr_email)
 		{
 			prev_translator_email=g_strdup(ph->tr_email);
@@ -324,30 +318,15 @@ static void gtranslator_header_edit_apply(GtkWidget * box, gint page_num, gpoint
 		update(ph->encoding, GTK_COMBO(enc_combo)->entry);
 #undef update
 	} else {
-#define replace(what,with,entry) GTR_FREE(what); what = g_strdup(with);\
+#define replace(what,with,entry) g_free(what); what = g_strdup(with);\
 	gtk_entry_set_text(GTK_ENTRY(entry), with);
 	
-		if(po->utf8)
+		if(ph->translator)
 		{
-			if(ph->translator)
-			{
-				prev_translator=g_strdup(ph->translator);
-				GTR_FREE(ph->translator);
-			}
-			
-			ph->translator=g_strdup(gtranslator_translator->name);
-			gtranslator_utf8_set_gtk_entry_from_utf8_string(translator, 
-				gtranslator_translator->name);
-		}
-		else
-		{
-			if(ph->translator)
-			{
-				prev_translator=g_strdup(ph->translator);
-			}
-
-			replace(ph->translator, gtranslator_translator->name, translator);
+			prev_translator=g_strdup(ph->translator);
 		}
+		
+		replace(ph->translator, gtranslator_translator->name, translator);
 
 		if(ph->tr_email)
 		{
@@ -381,7 +360,7 @@ static void gtranslator_header_edit_apply(GtkWidget * box, gint page_num, gpoint
 		/*
 		 * Rescue the old header comment and free it's variable.
 		 */
-		GTR_STRDUP(prev_header_comment, ph->comment);
+		prev_header_comment=g_strdup(ph->comment);
 		GTR_FREE(ph->comment);
 
 		/*
@@ -424,7 +403,11 @@ void gtranslator_header_edit_dialog(GtkWidget * widget, gpointer useless)
 	GtkWidget *label;
 	GtkWidget *foo_me_i_ve_been_wracked;
 
-	gtranslator_raise_dialog(e_header);
+	if(e_header != NULL) {
+		gtk_window_present(GTK_WINDOW(e_header));
+		return;
+	}
+
 	e_header = gnome_property_box_new();
 	gtk_window_set_title(GTK_WINDOW(e_header),
 			     _("gtranslator -- edit header"));
@@ -452,43 +435,32 @@ void gtranslator_header_edit_dialog(GtkWidget * widget, gpointer useless)
 	 */
 	ph->comment=gtranslator_header_comment_convert_for_view(ph->comment);
 
-	if(po->utf8)
-	{
-		gchar	*plain_comment_string=NULL;
-
-		plain_comment_string=gtranslator_utf8_get_plain_string(&ph->comment);
-		prj_comment=gtranslator_utils_attach_text_with_label(prj_page, 0,
-			plain_comment_string, _("Comments:"), gtranslator_header_edit_changed);
-	}
-	else
-	{
-		prj_comment=gtranslator_utils_attach_text_with_label(prj_page, 0, _("Comments:"),
-			ph->comment, gtranslator_header_edit_changed);
-	}
+	prj_comment=gtranslator_utils_attach_text_with_label(prj_page, 0, _("Comments:"),
+							     ph->comment, G_CALLBACK(gtranslator_header_edit_changed));
 	
 	gtk_widget_set_usize(prj_comment, 360, 90);
 	
 	prj_name =
 	    gtranslator_utils_attach_entry_with_label(prj_page, 1, _("Project name:"),
-	    			    ph->prj_name, gtranslator_header_edit_changed);
+	    			    ph->prj_name, G_CALLBACK(gtranslator_header_edit_changed));
 	prj_version =
 	    gtranslator_utils_attach_entry_with_label(prj_page, 2, _("Project version:"),
-	    			    ph->prj_version, gtranslator_header_edit_changed);
+	    			    ph->prj_version, G_CALLBACK(gtranslator_header_edit_changed));
 	pot_date =
 	    gtranslator_utils_attach_entry_with_label(prj_page, 3, _("Pot file creation date:"),
-				    ph->pot_date, gtranslator_header_edit_changed);
+				    ph->pot_date, G_CALLBACK(gtranslator_header_edit_changed));
 	gtk_widget_set_sensitive(pot_date, FALSE);
 	
 	po_date =
 	    gtranslator_utils_attach_entry_with_label(prj_page, 4, _("Po file revision date:"),
-				    ph->po_date, gtranslator_header_edit_changed);
+				    ph->po_date, G_CALLBACK(gtranslator_header_edit_changed));
 	gtk_widget_set_sensitive(po_date, FALSE);
 
 	if(ph->generator)
 	{
 		foo_me_i_ve_been_wracked =
 	    		gtranslator_utils_attach_entry_with_label(prj_page, 5, _("Generator:"),
-	    			ph->generator, gtranslator_header_edit_changed);
+	    			ph->generator, G_CALLBACK(gtranslator_header_edit_changed));
 		gtk_widget_set_sensitive(foo_me_i_ve_been_wracked, FALSE);
 	}
 
@@ -501,8 +473,8 @@ void gtranslator_header_edit_dialog(GtkWidget * widget, gpointer useless)
 	gtk_box_pack_start(GTK_BOX(lang_vbox), take_my_options, TRUE, TRUE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(take_my_options), 
 				     GtrPreferences.fill_header);
-	gtk_signal_connect(GTK_OBJECT(take_my_options), "toggled",
-			   GTK_SIGNAL_FUNC(take_my_options_toggled), NULL);
+	g_signal_connect(G_OBJECT(take_my_options), "toggled",
+			 G_CALLBACK(take_my_options_toggled), NULL);
 	/*
 	 * Language and translator options
 	 */
@@ -510,40 +482,28 @@ void gtranslator_header_edit_dialog(GtkWidget * widget, gpointer useless)
 	gtk_widget_set_sensitive(lang_page, !GtrPreferences.fill_header);
 	gtk_box_pack_start(GTK_BOX(lang_vbox), lang_page, TRUE, TRUE, 0);
 
-	if(po->utf8)
-	{
-		gchar	*plain_author_string=NULL;
-
-		plain_author_string=gtranslator_utf8_get_plain_string(&ph->translator);
-
-		translator=gtranslator_utils_attach_entry_with_label(lang_page, 1, 
-			_("Translator's name:"), plain_author_string, gtranslator_header_edit_changed);
-	}
-	else
-	{
-		translator=gtranslator_utils_attach_entry_with_label(lang_page, 1, 
-			_("Translator's name:"), ph->translator, gtranslator_header_edit_changed);
-	}
+	translator=gtranslator_utils_attach_entry_with_label(lang_page, 1, 
+							     _("Translator's name:"), ph->translator, G_CALLBACK(gtranslator_header_edit_changed));
 
 	tr_email =
 	    gtranslator_utils_attach_entry_with_label(lang_page, 2, _("Translator's e-mail:"),
-				    ph->tr_email, gtranslator_header_edit_changed);
+				    ph->tr_email, G_CALLBACK(gtranslator_header_edit_changed));
 	language_combo =
 	    gtranslator_utils_attach_combo_with_label(lang_page, 3, _("Language:"),
 				    languages_list, _(ph->language),
 				    FALSE,
-				    language_changed, NULL);
+				    G_CALLBACK(language_changed), NULL);
 	lg_combo =
 	    gtranslator_utils_attach_combo_with_label(lang_page, 4,
 				    _("Language group's e-mail:"),
 				    group_emails_list, ph->lg_email,
 				    TRUE,
-				    gtranslator_header_edit_changed, NULL);
+				    G_CALLBACK(gtranslator_header_edit_changed), NULL);
 	charset_combo =
 	    gtranslator_utils_attach_combo_with_label(lang_page, 5, _("Charset:"),
 				    encodings_list, ph->charset,
 				    FALSE,
-				    gtranslator_header_edit_changed, NULL);
+				    G_CALLBACK(gtranslator_header_edit_changed), NULL);
 
 	/*
 	 * Disable any charset changes directly from the header by making the
@@ -555,14 +515,14 @@ void gtranslator_header_edit_dialog(GtkWidget * widget, gpointer useless)
 	    gtranslator_utils_attach_combo_with_label(lang_page, 6, _("Encoding:"),
 				    bits_list, ph->encoding,
 				    FALSE,
-				    gtranslator_header_edit_changed, NULL);
+				    G_CALLBACK(gtranslator_header_edit_changed), NULL);
 	/*
 	 * Connect the signals
 	 */
-	gtk_signal_connect(GTK_OBJECT(e_header), "apply",
-			   GTK_SIGNAL_FUNC(gtranslator_header_edit_apply), NULL);
-	gtk_signal_connect(GTK_OBJECT(e_header), "close",
-			   GTK_SIGNAL_FUNC(gtranslator_utils_language_lists_free), NULL);
+	g_signal_connect(G_OBJECT(e_header), "apply",
+			 G_CALLBACK(gtranslator_header_edit_apply), NULL);
+	g_signal_connect(G_OBJECT(e_header), "close",
+			 G_CALLBACK(gtranslator_utils_language_lists_free), NULL);
 
 	gtranslator_dialog_show(&e_header, "gtranslator -- header");
 
@@ -576,7 +536,7 @@ void gtranslator_header_edit_dialog(GtkWidget * widget, gpointer useless)
 static void language_changed(GtkWidget * widget, gpointer useless)
 {
 	guint c = 0;
-	gchar *current = gtk_entry_get_text(GTK_ENTRY
+	G_CONST_RETURN gchar *current = gtk_entry_get_text(GTK_ENTRY
 					    (GTK_COMBO(language_combo)->entry));
 	while (languages[c].name != NULL) {
 		if (!g_strcasecmp(current, _(languages[c].name))) {
@@ -652,14 +612,7 @@ gchar *gtranslator_header_comment_convert_for_view(gchar *comment)
 
 	g_strfreev(stringarray);
 
-	if(po->utf8)
-	{
-		return gtranslator_utf8_get_plain_string(&mystring->str);
-	}
-	else
-	{
-		return mystring->str;
-	}
+	return mystring->str;
 }
 
 /*
@@ -698,14 +651,7 @@ gchar *gtranslator_header_comment_convert_for_save(gchar *comment)
 	
 	g_strfreev(stringarray);
 	
-	if(po->utf8)
-	{
-		return (gtranslator_utf8_get_utf8_string(&mystring->str));
-	}
-	else
-	{
-		return mystring->str;
-	}
+	return mystring->str;
 }
 
 static gchar * get_current_year(void)
@@ -735,7 +681,7 @@ void substitute(gchar **item, const gchar *bad, const gchar *good)
 	   (!strcmp(*item, bad)))
 	{
 		/* Replace it with copy of good one */
-		GTR_FREE(*item);
+		g_free(*item);
 		*item=g_strdup(good);
 		have_changed=TRUE;
 	}
