@@ -27,7 +27,7 @@
 
 #include <string.h>
 
-#include <libgnome/gnome-defs.h>
+//#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 
 /*
