@@ -1,5 +1,7 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
+ * 			GNOME I18N List <gnome-i18n@gnome.org>
+ * 			Guntupalli Karunakar <karunakar@freedomink.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -51,6 +53,10 @@ GtrLanguage languages[] = {
 	 N_("Belorussian"), "be", "windows-1251",
 	 "", "8bit"
 	},
+        {
+         N_("Bengali"), "bn", "UTF-8",
+         "gnome-translation@bengalinux.org", "8bit"
+        },		
 	{
 	 N_("Britton"), "br", "iso-8859-1",
 	 "", "8bit"
@@ -64,11 +70,11 @@ GtrLanguage languages[] = {
 	 "ca@dodds.net", "8bit"
 	},
 	{
-	 N_("Chinese/Simplified"), "zh_CN.GB2312", "GB2312",
+	 N_("Chinese/Simplified"), "zh_CN", "GB2312",
 	 "i18n-translation@lists.linux.net.cn", "8bit"
 	},
 	{
-	 N_("Chinese/Traditional"), "zh_TW.Big5", "Big5",
+	 N_("Chinese/Traditional"), "zh_TW", "Big5",
 	 "zh-l10n@linux.org.tw", "8bit"
 	},
 	{
@@ -135,6 +141,14 @@ GtrLanguage languages[] = {
 	 N_("Greek"), "el", "iso-8859-7",
 	 "nls@tux.hellug.gr", "8bit"
 	},
+	{
+	 N_("Gujarati"), "gu", "UTF-8",
+	 "indlinux-gujarati@lists.sourceforge.net", "8bit"
+	},
+	{
+	 N_("Hindi"), "hi", "UTF-8",
+	 "indlinux-hindi-gnome@lists.sourceforge.net", "8bit"
+	},
 	{
 	 N_("Hungarian"), "hu", "iso-8859-2",
 	 "hu@gnome.hu", "8bit"
@@ -155,6 +169,10 @@ GtrLanguage languages[] = {
 	 N_("Japanese"), "ja", "euc-jp",
 	 "gnome-translation@gnome.gr.jp", "8bit"
 	},
+	{
+	 N_("Kannada"), "kn", "UTF-8",
+	 "kannada@sharma-home.net", "8bit"
+	},
 	{
 	 N_("Korean"), "ko", "euc-kr",
 	 "ko@li.org", "8bit"
@@ -175,6 +193,10 @@ GtrLanguage languages[] = {
 	 N_("Maltese"), "mt", "iso-8859-3",
 	 "", "8bit"
 	},
+	{
+	 N_("Marathi"), "mr", "UTF-8",
+	 "indlinux-marathi@lists.sourceforge.net", "8bit"
+	},
 	{
 	 N_("Norwegian/Bokmaal"), "no", "iso-8859-1",
 	 "no@li.org", "8bit"
@@ -183,6 +205,10 @@ GtrLanguage languages[] = {
 	 N_("Norwegian/Nynorsk"), "nn", "iso-8859-1",
 	 "nn@li.org", "8bit"
 	},
+	{
+	 N_("Punjabi"), "pa", "UTF-8",
+	 "indlinux-punjabi@lists.sourceforge.net", "8bit"
+	},
 	{
 	 N_("Polish"), "pl", "iso-8859-2",
 	 "gnomepl@pandora.info.bielsko.pl", "8bit"
@@ -239,6 +265,10 @@ GtrLanguage languages[] = {
 	 N_("Tamil"), "ta", "tscii",
 	 "", "8bit"
 	},
+	{
+	 N_("Telugu"), "te", "UTF-8",
+	 "indlinux-telugu@lists.sourceforge.net", "8bit"
+	},
 	{
 	 N_("Thai"), "th", "tis-620",
 	 "", "8bit"
