@@ -1,5 +1,5 @@
 /*
- * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,13 +32,8 @@
 
 #include <time.h>
 
-#include <gnome-xml/parser.h>
-#include <gnome-xml/tree.h>
-
-#include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-util.h>
-
-#include <gal/util/e-xml-utils.h>
+#include <libxml/parser.h>
+#include <libxml/tree.h>
 
 /*
  * The GtrLearnBuffer structure which holds all informations/parts of the
@@ -256,7 +251,7 @@ static gchar *gtranslator_learn_buffer_escape_hash_entry(gchar *hstr)
 	g_return_val_if_fail(hstr!=NULL, NULL);
 
 	escaped_str=nautilus_str_replace_substring(hstr, "\"", "\\\"");
-	escaped_str=nautilus_str_replace_substring(escaped_str, "\n", "\\n\n");
+	escaped_str=nautilus_str_replace_substring(escaped_str, "\n", "\"\n\"");
 
 	return escaped_str;
 }
@@ -398,7 +393,8 @@ void gtranslator_learn_init()
 	gtranslator_learn_buffer=g_new0(GtrLearnBuffer, 1);
 	
 	gtranslator_learn_buffer->filename=g_strdup_printf(
-		"%s/.gtranslator/umtf/learn-buffer.xml", g_get_home_dir());
+		"%s/.gtranslator/umtf/personal-learn-buffer.xml", 
+			g_get_home_dir());
 
 	gtranslator_learn_buffer->hash=g_hash_table_new(g_str_hash, g_str_equal);
 	gtranslator_learn_buffer->resources=NULL;
@@ -407,14 +403,13 @@ void gtranslator_learn_init()
 	/*
 	 * Read in our autolearned xml document.
 	 */
-	if(g_file_test(gtranslator_learn_buffer->filename, G_FILE_TEST_ISFILE))
+	if(g_file_test(gtranslator_learn_buffer->filename, G_FILE_TEST_IS_REGULAR))
 	{
 		xmlNodePtr node;
 		
 		gtranslator_learn_buffer->doc=xmlParseFile(gtranslator_learn_buffer->filename);
 		g_return_if_fail(gtranslator_learn_buffer->doc!=NULL);
-
-		gtranslator_learn_buffer->encoding=e_xml_get_string_prop_by_name(gtranslator_learn_buffer->doc->xmlRootNode, "encoding");
+		gtranslator_learn_buffer->encoding=gtranslator_xml_get_string_prop_by_name_with_default(gtranslator_learn_buffer->doc->xmlRootNode, "encoding", "UTF-8");
 
 		gtranslator_learn_buffer->current_node=gtranslator_learn_buffer->doc->xmlRootNode->xmlChildrenNode;
 		g_return_if_fail(gtranslator_learn_buffer->current_node!=NULL);
@@ -471,10 +466,10 @@ void gtranslator_learn_init()
 				{
 					GtrLearnResource *resource=g_new0(GtrLearnResource, 1);
 
-					resource->package=e_xml_get_string_prop_by_name(resources_node, "package");
-					resource->updated=e_xml_get_string_prop_by_name(resources_node, "updated");
-					resource->premiereversion=e_xml_get_string_prop_by_name(resources_node, "premiereversion");
-					resource->index=e_xml_get_integer_prop_by_name(resources_node, "index");
+					resource->package=gtranslator_xml_get_string_prop_by_name_with_default(resources_node, "package", NULL);
+					resource->updated=gtranslator_xml_get_string_prop_by_name_with_default(resources_node, "updated", NULL);
+					resource->premiereversion=gtranslator_xml_get_string_prop_by_name_with_default(resources_node, "premiereversion", NULL);
+					resource->index=gtranslator_xml_get_integer_prop_by_name_with_default(resources_node, "index", 1);
 
 					/*
 					 * Add the current parsed in resource to the learn buffer's
@@ -583,11 +578,11 @@ void gtranslator_learn_shutdown()
 		 */
 		language_node=xmlNewChild(root_node, NULL, "language", NULL);
 		
-		e_xml_set_string_prop_by_name(language_node, "ename", 
+		gtranslator_xml_set_string_prop_by_name(language_node, "ename", 
 			gtranslator_translator->language->name);
-		e_xml_set_string_prop_by_name(language_node, "code", 
+		gtranslator_xml_set_string_prop_by_name(language_node, "code", 
 			gtranslator_translator->language->locale);
-		e_xml_set_string_prop_by_name(language_node, "email", 
+		gtranslator_xml_set_string_prop_by_name(language_node, "email", 
 			gtranslator_translator->language->group_email);
 	
 		/*
@@ -595,8 +590,8 @@ void gtranslator_learn_shutdown()
 		 */
 		translator_node=xmlNewChild(root_node, NULL, "translator", NULL);
 		
-		e_xml_set_string_prop_by_name(translator_node, "name", gtranslator_translator->name);
-		e_xml_set_string_prop_by_name(translator_node, "email", gtranslator_translator->email);
+		gtranslator_xml_set_string_prop_by_name(translator_node, "name", gtranslator_translator->name);
+		gtranslator_xml_set_string_prop_by_name(translator_node, "email", gtranslator_translator->email);
 	
 		/*
 		 * Set the UMTF date string for our internal GtrLearnBuffer.
@@ -658,11 +653,11 @@ void gtranslator_learn_shutdown()
 				/*
 				 * Write all the attributes for a resource entry.
 				 */
-				e_xml_set_string_prop_by_name(resource_node, "package", resource->package);
-				e_xml_set_string_prop_by_name(resource_node, "updated", resource->updated);
-				e_xml_set_string_prop_by_name(resource_node, "premiereversion", resource->premiereversion); 
+				gtranslator_xml_set_string_prop_by_name(resource_node, "package", resource->package);
+				gtranslator_xml_set_string_prop_by_name(resource_node, "updated", resource->updated);
+				gtranslator_xml_set_string_prop_by_name(resource_node, "premiereversion", (resource->premiereversion?resource->premiereversion:"1")); 
 				
-				e_xml_set_integer_prop_by_name(resource_node, "index", resource->index);
+				gtranslator_xml_set_integer_prop_by_name(resource_node, "index", resource->index);
 				
 				GTR_ITER(gtranslator_learn_buffer->resources);
 			}
@@ -828,7 +823,7 @@ void gtranslator_learn_export_to_po_file(const gchar *po_file)
 	fprintf(file, 
 "\nmsgid \"\"\n"
 "msgstr \"\"\n"
-"\"Project-Id-Version: gtranslator-learn-buffer %i\\n\"\n"
+"\"Project-Id-Version: gtranslator's learn buffer %i\\n\"\n"
 "\"POT-Creation-Date: %s\\n\"\n"
 "\"PO-Revision-Date: %s\\n\"\n"
 "\"Last-Translator: %s <%s>\\n\"\n"
@@ -862,9 +857,20 @@ void gtranslator_learn_export_to_po_file(const gchar *po_file)
  */
 void gtranslator_learn_string(const gchar *id_string, const gchar *str_string)
 {
+	gchar *id_dup, *str_dup;
+	
 	g_return_if_fail(id_string!=NULL);
 	g_return_if_fail(str_string!=NULL);
 
+	/*
+	 * Convert both entries to UTF-8 before adding to the learn buffer.
+	 */
+	id_dup=g_convert(id_string, -1, "UTF-8", po->header->charset,
+		NULL, NULL, NULL);
+
+	str_dup=g_convert(str_string, -1, "UTF-8", po->header->charset,
+		NULL, NULL, NULL);
+	
 	/*
 	 * Insert the id/str_string pair only if there's no entry for the
 	 *  id_string yet.
