@@ -1,5 +1,5 @@
 /*
- * (C) 2000-2002 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  *			Peeter Vois <peeter@gtranslator.org>
  * 
@@ -22,9 +22,9 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#include <gnome.h>
 
 #include "actions.h"
-#include "backend.h"
 #include "color-schemes.h"
 #include "defines.include"
 #include "dialogs.h"
@@ -50,12 +50,13 @@
 
 #include <gtk/gtkmain.h>
 
-#include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-init.h>
+#include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-window-icon.h>
 
 #include <libgnomevfs/gnome-vfs-init.h>
 
+#include <semerkent.h>
+
 /*
  * The static variables used in the poptTable.
  */
@@ -97,17 +98,13 @@ static struct poptOption gtranslator_options[] = {
 		"learn", 'l', POPT_ARG_STRING, &learn_file,
 		0, N_("Learn the file completely & exit"), N_("FILENAME")
 	},
-	{
-		"no-modules", 'n', POPT_ARG_NONE, &no_modules,
-		0, N_("Don't load any backend modules"), NULL
-	},
 	{
 		"webalize", 'w', POPT_ARG_STRING, &save_html_output_file,
 		0, N_("HTML file to write to"), N_("HTMLFILE")
 	},
 	{
 		"nosyntax", 'y', POPT_ARG_NONE, &nosyntax,
-		0, N_("Don't highlight syntax"), NULL 
+		0, N_("Don't highlight syntax - FIXME: We're always non-syntaxed currently! Sorry..."), NULL 
 	},
 	POPT_AUTOHELP {NULL}
 };
@@ -119,7 +116,7 @@ int main(int argc, char *argv[])
 	
 	poptContext 	context;
 	
-	const char 	**args;
+	const char 	**args=NULL;
 	
 	GError		*error=NULL;
 
@@ -127,6 +124,7 @@ int main(int argc, char *argv[])
 	 * Initialize gettext.
 	 */ 
 	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset(PACKAGE, "UTF-8");
 	textdomain(PACKAGE);
 
 	/*
@@ -158,8 +156,13 @@ int main(int argc, char *argv[])
 	/*
 	 * Initialize gtranslator within libgnomeui.
 	 */
-	gnome_init_with_popt_table("gtranslator", VERSION, argc, argv,
-		gtranslator_options, 0, &context);
+	gnome_program_init("gtranslator", VERSION, LIBGNOMEUI_MODULE, 
+			   argc, argv,
+			   GNOME_PARAM_POPT_TABLE, gtranslator_options, 
+			   GNOME_PROGRAM_STANDARD_PROPERTIES,
+			   NULL);
+	/* XXX fix it! */
+	// 0, &context);
 
 	/*
 	 * Show up build information if desired.
@@ -167,18 +170,15 @@ int main(int argc, char *argv[])
 	if(build_information)
 	{
 		#define NICE_PRINT(x); \
-			g_print("\n\t\t%s", x); \
-			g_print("\n\t");
+			g_print("\n\t%s\n", x);
 
-		g_print("\t");
+		g_print("\t\n");
 		g_print(_("gtranslator build information/specs:"));
-		g_print("\n\n\t");
+		g_print("\n\n");
 		g_print(_("Version and build date:"));
 		NICE_PRINT(BUILD_STRING);
-		g_print(_("Build GLib/Gtk+/GNOME versions:"));
+		g_print(_("Build GLib / Gtk+ / GNOME / XML versions:"));
 		NICE_PRINT(BUILD_VERSIONS);
-		g_print(_("Backends directory:"));
-		NICE_PRINT(BACKENDS_DIR);
 		g_print(_("Colorschemes directory:"));
 		NICE_PRINT(SCHEMESDIR);
 		g_print(_("Scripts directory:"));
@@ -187,6 +187,8 @@ int main(int argc, char *argv[])
 		NICE_PRINT(WINDOW_ICON);
 		g_print(_("Own locale directory:"));
 		NICE_PRINT(GNOMELOCALEDIR);
+		g_print(_("Default learn buffer file location:"));
+		NICE_PRINT("~/.gtranslator/umtf/personal-learn-buffer.xml");
 		g_print("\n");
 
 		#undef NICE_PRINT
@@ -203,34 +205,6 @@ int main(int argc, char *argv[])
 	 */
 	gtranslator_preferences_read();
 
-	/*
-	 * If the loading of the modules isn't inhibited, try to load all
-	 *  backends.
-	 */
-	if(!GtrPreferences.load_backends || no_modules)
-	{
-		backends=NULL;
-	}
-	else
-	{
-		/*
-		 * Test first if the local libgmodule supports modules at all.
-		 */
-		if(!g_module_supported())
-		{
-			g_warning(_("GModule implementation doesn't support loading dynamic modules!"));
-			backends=NULL;
-		}
-		else
-		{
-			/*
-			 * Load all backends from the default backends 
-			 *  directory.
-			 */
-			 gtranslator_backend_open_all_backends(BACKENDS_DIR);
-		}
-	}
-
 	/*
 	 * Show the application window with icon.
 	 */
@@ -263,11 +237,11 @@ int main(int argc, char *argv[])
 		/*
 		 * Connect the signals needed for session management.
 		 */
-		gtk_signal_connect(GTK_OBJECT(client), "save_yourself",
-				   GTK_SIGNAL_FUNC(gtranslator_session_sleep),
+		g_signal_connect(G_OBJECT(client), "save_yourself",
+				 G_CALLBACK(gtranslator_session_sleep),
 				   (gpointer) argv[0]);
-		gtk_signal_connect(GTK_OBJECT(client), "die",
-				   GTK_SIGNAL_FUNC(gtranslator_session_die), NULL);
+		g_signal_connect(G_OBJECT(client), "die",
+				 G_CALLBACK(gtranslator_session_die), NULL);
 	}
 
 	/*
@@ -301,7 +275,7 @@ int main(int argc, char *argv[])
 	/*
 	 * Test if there's a crash recovery file lying around in ~/.gtranslator.
 	 */
-	if(g_file_exists(gtranslator_runtime_config->crash_filename))
+	if(g_file_test(gtranslator_runtime_config->crash_filename, G_FILE_TEST_EXISTS))
 	{
 		gtranslator_rescue_file_dialog();
 	}
@@ -325,7 +299,7 @@ int main(int argc, char *argv[])
 	 * If there are any files given on command line, open them
 	 */
 	file_opened = FALSE;
-	args = poptGetArgs(context);
+	//	args = poptGetArgs(context);
 
 	/*
 	 * Auto translate the given file argument and exit without starting the
@@ -397,7 +371,7 @@ int main(int argc, char *argv[])
 		}
 	}
 	
-	poptFreeContext(context);
+	//	poptFreeContext(context);
 
 	/*
 	 * Disable the buttons if no file is opened.
