@@ -1,6 +1,6 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
- *		Gediminas Paulauskas <menesis@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
+ *			Gediminas Paulauskas <menesis@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,15 +29,14 @@ extern GnomeUIInfo the_menus[];
 extern GnomeUIInfo the_file_menu[];
 extern GnomeUIInfo the_last_files_menus[];
 extern GnomeUIInfo the_edit_menu[];
-extern GnomeUIInfo the_messages_menu[];
-extern GnomeUIInfo the_msg_status_menu[];
+
+extern GnomeUIInfo the_view_menu[];
 extern GnomeUIInfo the_colorschemes_menu[];
-extern GnomeUIInfo the_settings_menu[];
+
+extern GnomeUIInfo the_go_menu[];
 extern GnomeUIInfo the_help_menu[];
 
 extern GnomeUIInfo the_toolbar[];
 extern GnomeUIInfo the_navibar[];
 
-extern GnomeUIInfo the_main_popup_menu[];
-
 #endif
