@@ -1,5 +1,6 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
+ * 			Thomas Ziehmer <thomas@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +24,6 @@
 
 #include "actions.h"
 #include "comment.h"
-#include "formats.h"
 #include "gtkspell.h"
 #include "gui.h"
 #include "learn.h"
@@ -162,46 +162,28 @@ void gtranslator_message_show(GtrMsg *msg)
 	if(GtrPreferences.dot_char)
 	{
 		gchar *temp;
+		gchar *old;
 
-		temp = g_strdup(msg->msgid);
-		gtranslator_utils_invert_dot(temp);
+		g_return_if_fail(msg!=NULL);
+		g_return_if_fail(msg->msgid!=NULL);
 		
-		gtranslator_insert_text(GTK_TEXT(text_box), temp);
+		temp = gtranslator_utils_invert_dot(msg->msgid);
+		gtranslator_insert_text(text_box, temp);
 		
 		GTR_FREE(temp);
 
 		if (msg->msgstr) {
-			if(po->utf8)
-			{
-				temp=gtranslator_utf8_get_plain_msgstr(&msg);
-			}
-			else
-			{
-				temp=g_strdup(msg->msgstr);
-			}
+			temp = gtranslator_utils_invert_dot(msg->msgstr);
 			
-			gtranslator_utils_invert_dot(temp);
-			
-			gtranslator_insert_text(GTK_TEXT(trans_box), temp);
+			gtranslator_insert_text(trans_box, temp);
 			
 			GTR_FREE(temp);
 		}
 	} else {
-		gtranslator_insert_text(GTK_TEXT(text_box), msg->msgid);
-
-		if(po->utf8)
-		{
-			gchar *text=gtranslator_utf8_get_plain_msgstr(&msg);
-			
-			gtranslator_insert_text(GTK_TEXT(trans_box), text);
-
-		}
-		else
-		{
-			gtranslator_insert_text(GTK_TEXT(trans_box), msg->msgstr);
-		}
+		gtranslator_insert_text(text_box, msg->msgid);
+		gtranslator_insert_text(trans_box, msg->msgstr);
 	}
-	
+#ifdef NOT_PORTED	
 	/*
 	 * Use instant spell checking via gtkspell only if the corresponding
 	 *  setting in the preferences is set.
@@ -240,35 +222,37 @@ void gtranslator_message_show(GtrMsg *msg)
 		 */ 
 		gtkspell_attach(GTK_TEXT(trans_box));
 	}
-#define set_active(number,flag) \
-	gtk_check_menu_item_set_active(\
-		(GtkCheckMenuItem *)(the_msg_status_menu[number].widget),\
-		msg->status & flag);
-	set_active(0, GTR_MSG_STATUS_TRANSLATED);
-	set_active(1, GTR_MSG_STATUS_FUZZY);
-#undef set_active
+#endif //NOT_PORTED
+
+	gtk_check_menu_item_set_active(
+		GTK_CHECK_MENU_ITEM(the_edit_menu[19].widget),
+		msg->status & GTR_MSG_STATUS_FUZZY
+	);
 	nothing_changes = FALSE;
 	message_changed = FALSE;
 }
 
 void gtranslator_message_update(void)
 {
-	guint 
-		len,
-		pos;
-		
+  guint len; 
+  //		pos;
+	GtkTextIter start, end;
 	GtrMsg 
 		*msg = GTR_MSG(po->current->data);
 		
 	if (!message_changed)
 		return;
-	pos = gtk_editable_get_position( GTK_EDITABLE(trans_box) );
-	gtk_text_freeze( GTK_TEXT(trans_box) );
-	len = gtk_text_get_length(GTK_TEXT(trans_box));
+	//	pos = gtk_editable_get_position( GTK_EDITABLE(trans_box) );
+	// gtk_text_freeze( GTK_TEXT(trans_box) );
+	len = gtk_text_buffer_get_char_count(gtk_text_view_get_buffer(trans_box));
 	if (len) {
+		gtk_text_buffer_get_bounds(gtk_text_view_get_buffer(trans_box), &start, &end);
+
 		/* Make both strings end with or without endline */
+		// XXX fix it
+		/*
 		if (msg->msgid[strlen(msg->msgid) - 1] == '\n') {
-			if (GTK_TEXT_INDEX(GTK_TEXT(trans_box), len - 1)
+			if (GTK_TEXT_INDEX(trans_box), len - 1)
 			    != '\n')
 				gtk_editable_insert_text(
 				    GTK_EDITABLE(trans_box), "\n", 1, &len);
@@ -280,24 +264,33 @@ void gtranslator_message_update(void)
 				len--;
 			}
 		}
-		
-		GTR_FREE(msg->msgstr);
+		*/
 
+		GTR_FREE(msg->msgstr);
+		/*
 		if(po->utf8)
 		{
-			msg->msgstr=gtranslator_utf8_get_gtk_text_as_utf8_string(trans_box);
+			msg->msgstr=gtranslator_utf8_get_gtk_text_as_utf8_string(GTK_WIDGET(trans_box));
 		}
 		else
 		{
 			msg->msgstr=gtk_editable_get_chars(
 				GTK_EDITABLE(trans_box), 0, len);
 		}
+		*/
+		// XXX we always work with utf-8
 
+		msg->msgstr = gtk_text_buffer_get_text(gtk_text_view_get_buffer(trans_box), &start, &end, FALSE);
+		
 		/*
 		 * If spaces were substituted with dots, replace them back
 		 */
-		if(GtrPreferences.dot_char)
-			gtranslator_utils_invert_dot(msg->msgstr);
+		if(GtrPreferences.dot_char) {
+			gchar *old;
+			old = msg->msgstr;
+			msg->msgstr = gtranslator_utils_invert_dot(old);
+			g_free(old);
+		}
 		if (!(msg->status & GTR_MSG_STATUS_TRANSLATED)) {
 			msg->status |= GTR_MSG_STATUS_TRANSLATED;
 			po->translated++;
@@ -317,20 +310,6 @@ void gtranslator_message_update(void)
 		po->translated--;
 	}
 	
-	/*
-	 * Check the formats of the now updated GtrMsg -- a nerves-killing new
-	 *  feature I know...
-	 */
-	if(GtrPreferences.check_formats)
-	{
-		if(!gtranslator_formats_check(msg))
-		{
-			gtranslator_utils_error_dialog(
-			_("The translation for message `%s'\n\
-contains syntactical errors!"), msg->msgid);
-		}
-	}
-
 	message_changed = FALSE;
 	
 	/*
@@ -355,8 +334,8 @@ contains syntactical errors!"), msg->msgid);
 	{
 		gtranslator_actions_enable(ACT_REMOVE_ALL_TRANSLATIONS);
 	}
-	gtk_text_thaw( GTK_TEXT(trans_box) );
-	gtk_editable_set_position( GTK_EDITABLE(trans_box), pos );
+	//	gtk_text_thaw( GTK_TEXT(trans_box) );
+	//	gtk_editable_set_position( GTK_EDITABLE(trans_box), pos );
 }
 
 void gtranslator_message_change_status(GtkWidget  * item, gpointer which)
