@@ -53,17 +53,12 @@
 #include <gtk/gtkmain.h>
 #include <gtk/gtklabel.h>
 
-#include <libgnome/gnome-util.h>
-
 #include <libgnomeui/gnome-appbar.h>
 #include <libgnomeui/gnome-app-util.h>
 #include <libgnomeui/gnome-dialog-util.h>
 #include <libgnomeui/gnome-messagebox.h>
-#include <libgnomeui/gnome-stock.h>
 #include <libgnomeui/gnome-uidefs.h>
 
-#include <gal/e-paned/e-paned.h>
-
 /* Global variables */
 GtrPo *po;
 gboolean file_opened;
@@ -73,7 +68,7 @@ guint autosave_source_tag=1;
 /*
  * These are to be used only inside this file
  */
-static void append_line(gchar ** old, const gchar * tail);
+static void append_line(gchar ** old, const gchar * tail, gboolean continuation);
 static gboolean add_to_obsolete(gchar *comment);
 static void write_the_message(gpointer data, gpointer fs);
 static gchar *restore_msg(const gchar * given);
@@ -97,32 +92,17 @@ static void check_msg_status(GtrMsg * msg)
  * unneeded \'s and "'s and replaces \\n with real newline.
  * Then appends this to *old and updates the pointer.
  */
-static void append_line(gchar ** old, const gchar * tail)
+static void append_line(gchar ** old, const gchar * tail, gboolean continuation)
 {
 	gchar *to_add = g_new(gchar, strlen(tail));
 	gchar *result;
 	gint s, d = 0;
+
+	if (continuation)
+		to_add[d++] = '\n';
+
 	for (s = 1; s < strlen(tail) - 1; s++) {
-		if (tail[s] == '\\') {
-			s++;
-			if (tail[s] == 'n')
-				to_add[d++] = '\n';
-			else if(tail[s] == 'r')
-				to_add[d++] = '\r';
-			else if (tail[s] == 't')
-				to_add[d++] = '\t';
-			else if ((tail[s] == '"') || (tail[s] == '\\'))
-				to_add[d++] = tail[s];
-			else {
-				to_add[d++] = '\\';
-				to_add[d++] = tail[s];
-				g_warning
-				    (_("New escaped char found: \\%c\nAdd this to parse.c, line %i."),
-				     tail[s], __LINE__);
-			}
-		} else {
-			to_add[d++] = tail[s];
-		}
+		to_add[d++] = tail[s];
 	}
 	to_add[d] = 0;
 	if (*old == NULL)
@@ -173,8 +153,9 @@ void gtranslator_parse(const gchar *filename)
 
 	g_return_if_fail(filename!=NULL);
 
-	base=g_basename(filename);
+	base=g_path_get_basename(filename);
 	g_return_if_fail(base[0]!='\0');
+	g_free(base);
 
 	po = g_new0(GtrPo, 1);
 
@@ -230,6 +211,11 @@ void gtranslator_parse(const gchar *filename)
 	else
 	{
 		gtranslator_message_status_set_fuzzy(FIRST_MSG, first_is_fuzzy);
+
+		/*
+		 * Provide a default po->header to avoid segfaults (#62244)
+		 */
+		po->header=gtranslator_header_create_from_prefs();
 	}
 	
 	file_opened = TRUE;
@@ -250,6 +236,15 @@ void gtranslator_parse(const gchar *filename)
 	}
 
 	po->locale_charset=gtranslator_utils_get_locale_charset();
+	
+	/* FIXME: converting the messages to UTF8 there since I don't
+	   know the parsing code, and I don't feel like figuring it out
+	   so I temporarily put this here to ensure all the strings are 
+	   properly encoded. Please fix it...
+	*/
+	if (po->utf8 == FALSE) {
+		gtranslator_utf8_convert_po_to_utf8();
+	}
 
 	/*
 	 * Set the current message to the first message.
@@ -288,7 +283,13 @@ gboolean gtranslator_parse_core(void)
 	while ((line = gtranslator_utils_getline (fs)) != NULL) {
 		
 		lines++;
-		
+
+		/*
+		 * Warn if not valid UTF-8
+		 */
+		if (!g_utf8_validate(line, strlen(line), NULL))
+			g_warning("%s:%d: line contains invalid UTF-8", po->filename, lines);
+
 		/*
 		 * If it's a comment, no matter of what kind. It belongs to
 		 * the message pair below
@@ -332,7 +333,7 @@ gboolean gtranslator_parse_core(void)
 				 */
 				comment_ok = TRUE;
 				if (line[8] != '\0')
-					append_line(&msg->msgid, &line[6]);
+					append_line(&msg->msgid, &line[6], FALSE);
 			} 
 			/*
 			 * If it's a msgstr. 
@@ -344,7 +345,7 @@ gboolean gtranslator_parse_core(void)
 				 */
 				msgid_ok = TRUE;
 				if (line[9] != '\0')
-					append_line(&msg->msgstr, &line[7]);
+					append_line(&msg->msgstr, &line[7], FALSE);
 			}
 			else
 			/*
@@ -354,12 +355,12 @@ gboolean gtranslator_parse_core(void)
 				if((comment_ok == TRUE) &&
 				   (msgid_ok == FALSE))
 				{
-					append_line(&msg->msgid, line);
+					append_line(&msg->msgid, line, TRUE);
 				}
 				else if((msgid_ok == TRUE) &&
 					(msgstr_ok == FALSE))
 				{
-					append_line(&msg->msgstr, line);
+					append_line(&msg->msgstr, line, TRUE);
 				}
 				else if((comment_ok == FALSE) &&
 					(msgid_ok == FALSE) &&
@@ -441,12 +442,12 @@ gboolean gtranslator_parse_core(void)
  */
 void gtranslator_parse_main(const gchar *filename)
 {
-	gchar 	*title;
-
+  gchar 	*title;
+  gchar         *base;
 	/*
 	 * Test if such a file does exist.
 	 */
-	if(!g_file_exists(filename))
+	if(!g_file_test(filename, G_FILE_TEST_EXISTS))
 	{
 		gtranslator_utils_error_dialog(
 			_("The file `%s' doesn't exist at all!"),
@@ -565,13 +566,9 @@ void gtranslator_parse_main(const gchar *filename)
 	/*
 	 * Test if the filename is NOT equivalent to our temp files' names.
 	 */
-	if(nautilus_strcasecmp(g_basename(po->filename), 
-		gtranslator_runtime_config->temp_filename) || 
-	   nautilus_strcasecmp(g_basename(po->filename),
-	   	gtranslator_runtime_config->backend_filename) ||
-	   nautilus_strcasecmp(g_basename(po->filename),
-	   	gtranslator_runtime_config->crash_filename))
-		
+	base = g_path_get_basename(po->filename);
+	if(nautilus_strcasecmp(base, gtranslator_runtime_config->temp_filename) || 
+	   nautilus_strcasecmp(base, gtranslator_runtime_config->crash_filename))
 	{
 		gtranslator_history_add(po->filename,
 			po->header->prj_name, po->header->prj_version);
@@ -580,6 +577,7 @@ void gtranslator_parse_main(const gchar *filename)
 		gtk_window_set_title(GTK_WINDOW(gtranslator_application), title);
 		GTR_FREE(title);
 	}
+	g_free(base);
 
 	/*
 	 * Update the recent files list.
@@ -609,7 +607,7 @@ void gtranslator_parse_main(const gchar *filename)
 void gtranslator_parse_the_file_from_file_dialog(GtkWidget * widget, gpointer of_dlg)
 {
 	gchar *po_file;
-	po_file = gtk_file_selection_get_filename(GTK_FILE_SELECTION(of_dlg));
+	po_file = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(of_dlg)));
 
 	gtranslator_file_dialogs_store_directory(po_file);
 
@@ -633,7 +631,7 @@ static gchar *restore_msg(const gchar * given)
 {
 	gchar *result;
 	GString *rest;
-	gint s, lines = 0, here = 8;
+	gint s, lines = 0;
 
 	if(!given)
 	{
@@ -643,46 +641,11 @@ static gchar *restore_msg(const gchar * given)
 	rest = g_string_sized_new(strlen(given));
 	for (s = 0; s < strlen(given); s++) {
 		if (given[s] == '\n') {
-			if ((!lines) && (s + 1 < strlen(given))) {
-				lines++;
-				g_string_prepend(rest, "\"\n\"");
-			}
-			if ((s + 1 < strlen(given)) && (here < 78)) {
-				g_string_append(rest, "\\n\"\n\"");
-				here = 0;
-				lines++;
-			} else
-				g_string_append(rest, "\\n");
-		} else if (given[s] == '\"') {
-			g_string_append(rest, "\\\"");
-			here++;
-		} else if (given[s] == '\t') {
-			g_string_append(rest, "\\t");
-			here++;
-		} else if (given[s] == '\\') {
-			g_string_append(rest, "\\\\");
-			here++;
+			g_string_append(rest, "\"\n\"");
+			lines++;
 		} else {
 			g_string_append_c(rest, given[s]);
 		}
-		here++;
-		if (here > 78) {
-			if (!lines) {
-				g_string_prepend(rest, "\"\n\"");
-				here -= 7;
-			} else {
-				if(rest->str)
-				{
-					g_string_insert(rest,
-							(strrchr(rest->str, ' ') -
-							 rest->str) + 1, "\"\n\"");
-					here =
-					    rest->len - (strrchr(rest->str, '"') -
-							 rest->str);
-				}			 
-			}
-			lines++;
-		}
 	}
 	result = rest->str;
 	g_string_free(rest, FALSE);
@@ -879,7 +842,7 @@ Your file should likely be named '%s.po'."),
 void gtranslator_save_file_dialog(GtkWidget * widget, gpointer sfa_dlg)
 {
 	gchar *po_file;
-	po_file = gtk_file_selection_get_filename(GTK_FILE_SELECTION(sfa_dlg));
+	po_file = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(sfa_dlg)));
 	if (!gtranslator_save_file(po_file))
 		return;
 	GTR_FREE(po->filename);
@@ -958,7 +921,7 @@ void gtranslator_file_close(GtkWidget * widget, gpointer useless)
 	gtranslator_text_boxes_clean();
 	gtk_label_set_text(GTK_LABEL(extra_content_view->comment), "");
 	gtk_widget_set_sensitive(GTK_WIDGET(extra_content_view->edit_button), FALSE);
-	e_paned_set_position(E_PANED(content_pane), 0);
+	gtk_paned_set_position(GTK_PANED(content_pane), 0);
 	
 	gtranslator_actions_set_up_state_no_file();
 
@@ -966,7 +929,7 @@ void gtranslator_file_close(GtkWidget * widget, gpointer useless)
 	 * Set blank status, progress and window title
 	 */
 	gnome_appbar_clear_stack(GNOME_APPBAR(gtranslator_application_bar));
-	gnome_appbar_set_progress(GNOME_APPBAR(gtranslator_application_bar), 0.00000);
+	gnome_appbar_set_progress_percentage(GNOME_APPBAR(gtranslator_application_bar), 0.00000);
 	gtk_window_set_title(GTK_WINDOW(gtranslator_application), _("gtranslator"));
 
 	/*
@@ -1141,7 +1104,7 @@ void compile(GtkWidget * widget, gpointer useless)
 	/*
 	 * Check if msgfmt is available on the system.
 	 */
-	if(!gnome_is_program_in_path("msgfmt"))
+	if(!g_find_program_in_path("msgfmt"))
 	{
 		gtranslator_utils_error_dialog(_("Sorry, msgfmt isn't available on your system!"));
 		return;
@@ -1236,9 +1199,8 @@ void gtranslator_set_progress_bar(void)
 		/*
 		 * Set the progressbar status.
 		 */
-		gnome_appbar_set_progress(
+		gnome_appbar_set_progress_percentage(
 			GNOME_APPBAR(gtranslator_application_bar),
 			percentage);
 	}
 }
-
