@@ -36,9 +36,6 @@
 #include "utils.h"
 #include "utils_gui.h"
 
-#include <libgnome/gnome-util.h>
-#include <libgnomeui/libgnomeui.h>
-
 /*
  * The callbacks:
  */
@@ -62,20 +59,20 @@ static GtkWidget
 static GtkWidget
 	*authors_name, *authors_email, *authors_language,
 	*mime_type, *encoding, *lcode, *lg_email, *dictionary_file,
-	*scheme_file, *autosave_suffix, *compile_output_dir;
+	*scheme_file, *autosave_suffix;
 
 /*
  * The toggle buttons used in the preferences box:
  */
 static GtkWidget
 	*warn_if_fuzzy, *unmark_fuzzy, *save_geometry_tb,
-	*enable_popup_menu, *use_dot_char, *use_update_function,
+	*use_dot_char, *use_update_function,
 	*check_recent_files, *own_fonts, *own_colors, *use_own_dict,
 	*instant_spell_checking, *keep_obsolete, *autosave,
 	*autosave_with_suffix, *sweep_compile_file, *use_learn_buffer,
 	*show_messages_table, *rambo_function, *use_own_mt_colors,
 	*collapse_translated_entries, *auto_learn, *fuzzy_matching,
-	*load_backends, *show_comment, *highlight, *check_formats;
+	*show_comment, *highlight;
 
 /*
  * The timeout GtkSpinButton:
@@ -99,6 +96,11 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	gchar	*old_colorscheme=NULL;
 	GtkObject *adjustment;
 	
+	if(prefs != NULL) {
+		gtk_window_present(GTK_WINDOW(prefs));
+		return;
+	}
+
 	/*
 	 * Create the preferences box... 
 	 */
@@ -115,9 +117,9 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	second_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		5, 2, _("Language settings"));
 	third_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
-		5, 1, _("Po file editing"));
+		4, 1, _("Po file editing"));
 	fourth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
-		10, 1, _("Miscellaneous"));
+		9, 1, _("Miscellaneous"));
 	fifth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
 		3, 2, _("Recent files & spell checking"));
 	sixth_page = gtranslator_utils_append_page_to_preferences_dialog(prefs,
@@ -134,10 +136,10 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	 */
 	authors_name =
 	    gtranslator_utils_attach_entry_with_label(first_page, 0, _("Author's name:"),
-		gtranslator_translator->name, gtranslator_preferences_dialog_changed);
+		gtranslator_translator->name, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	authors_email =
 	    gtranslator_utils_attach_entry_with_label(first_page, 1, _("Author's EMail:"),
-		gtranslator_translator->email, gtranslator_preferences_dialog_changed);
+		gtranslator_translator->email, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	/*
 	 * Create, attach, and connect all the combo boxes with labels. 
@@ -148,97 +150,84 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	    gtranslator_utils_attach_combo_with_label(second_page, 0, _("Language:"),
 				    languages_list, gtranslator_translator->language->name,
 				    FALSE,
-				    gtranslator_preferences_dialog_changed, GINT_TO_POINTER(1));
+				    G_CALLBACK(gtranslator_preferences_dialog_changed), GINT_TO_POINTER(1));
 	lcode =
 	    gtranslator_utils_attach_combo_with_label(second_page, 1, _("Language code:"),
 				    lcodes_list, gtranslator_translator->language->locale,
 				    FALSE,
-				    gtranslator_preferences_dialog_changed, GINT_TO_POINTER(2));
+				    G_CALLBACK(gtranslator_preferences_dialog_changed), GINT_TO_POINTER(2));
 	lg_email =
 	    gtranslator_utils_attach_combo_with_label(second_page, 2,
 				    _("Language group's EMail:"),
 				    group_emails_list, gtranslator_translator->language->group_email,
 				    TRUE,
-				    gtranslator_preferences_dialog_changed, NULL);
+				    G_CALLBACK(gtranslator_preferences_dialog_changed), NULL);
 	mime_type =
 	    gtranslator_utils_attach_combo_with_label(second_page, 3, _("Charset:"),
 				    encodings_list, gtranslator_translator->language->encoding,
 				    FALSE,
-				    gtranslator_preferences_dialog_changed, NULL);
+				    G_CALLBACK(gtranslator_preferences_dialog_changed), NULL);
 	encoding =
 	    gtranslator_utils_attach_combo_with_label(second_page, 4, _("Encoding:"),
 				    bits_list, gtranslator_translator->language->bits,
 				    FALSE,
-				    gtranslator_preferences_dialog_changed, NULL);
+				    G_CALLBACK(gtranslator_preferences_dialog_changed), NULL);
 	/*
 	 * Create, attach, and connect the toggle buttons.
 	 */
 	unmark_fuzzy =
 	    gtranslator_utils_attach_toggle_with_label(third_page, 0,
 		_("Remove fuzzy status if message changed"),
-		GtrPreferences.unmark_fuzzy, gtranslator_preferences_dialog_changed);
+		GtrPreferences.unmark_fuzzy, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	warn_if_fuzzy =
 	    gtranslator_utils_attach_toggle_with_label(third_page, 1,
 		_("Warn if the po file contains fuzzy translations"),
-		GtrPreferences.warn_if_fuzzy, gtranslator_preferences_dialog_changed);
+		GtrPreferences.warn_if_fuzzy, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	keep_obsolete =
 	    gtranslator_utils_attach_toggle_with_label(third_page, 2,
 		_("Keep obsolete messages in the po files"),
-		GtrPreferences.keep_obsolete, gtranslator_preferences_dialog_changed);
+		GtrPreferences.keep_obsolete, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	highlight =
 	    gtranslator_utils_attach_toggle_with_label(third_page, 3,
 	    	_("Highlight syntax of the translation messages"),
-		GtrPreferences.highlight, gtranslator_preferences_dialog_changed);
-
-	check_formats =
-	    gtranslator_utils_attach_toggle_with_label(third_page, 4,
-	    	_("Check messages for syntactical correctness"),
-		GtrPreferences.check_formats, gtranslator_preferences_dialog_changed);
+		GtrPreferences.highlight, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
+	
 	/*
 	 * The fourth page with the popup menu & the dot_char.
 	 */
 	use_dot_char=gtranslator_utils_attach_toggle_with_label(fourth_page, 0,
 		_("Use special character to indicate free space"),
-		GtrPreferences.dot_char, gtranslator_preferences_dialog_changed);
-	enable_popup_menu=gtranslator_utils_attach_toggle_with_label(fourth_page, 2,
-		_("Enable the popup menu"),
-		GtrPreferences.popup_menu, gtranslator_preferences_dialog_changed);	
+		GtrPreferences.dot_char, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	use_update_function=gtranslator_utils_attach_toggle_with_label(fourth_page, 3,
 		_("Enable the functionality to update a po file from within gtranslator"),
-		GtrPreferences.update_function, gtranslator_preferences_dialog_changed);
+		GtrPreferences.update_function, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	rambo_function=gtranslator_utils_attach_toggle_with_label(fourth_page, 4,
 		_("Enable the functionality to remove all translations from a po file"),
-		GtrPreferences.rambo_function, gtranslator_preferences_dialog_changed);
+		GtrPreferences.rambo_function, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	sweep_compile_file=gtranslator_utils_attach_toggle_with_label(fourth_page,
 		5, _("Delete compiled files (e.g. \"project.gmo\")"),
-		GtrPreferences.sweep_compile_file, gtranslator_preferences_dialog_changed);
-	compile_output_dir=gtranslator_utils_attach_entry_with_label(fourth_page,
-		6, _("Directory to put compiled po files into"),
-		GtrPreferences.compile_output_dir, gtranslator_preferences_dialog_changed);
-	load_backends=gtranslator_utils_attach_toggle_with_label(fourth_page,
-		7, _("Load all backends on startup"),
-		GtrPreferences.load_backends, gtranslator_preferences_dialog_changed);
+		GtrPreferences.sweep_compile_file, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	save_geometry_tb=gtranslator_utils_attach_toggle_with_label(fourth_page,
-		8, _("Save geometry on exit & restore it on startup"),
-		GtrPreferences.save_geometry, gtranslator_preferences_dialog_changed);
+		6, _("Save geometry on exit & restore it on startup"),
+		GtrPreferences.save_geometry, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	show_comment=gtranslator_utils_attach_toggle_with_label(fourth_page,
-		9, _("Show instant comment view in the main pane"),
-		GtrPreferences.show_comment, gtranslator_preferences_dialog_changed);
+		7, _("Show instant comment view in the main pane"),
+		GtrPreferences.show_comment, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	
 	/*
 	 * The fifth page with the Recent files options.
 	 */
 	max_history_entries=gtranslator_utils_attach_spin_with_label(fifth_page, 0, 
 		_("Maximum number of entries in the recent files' list:"), 3, 15, 
-		GtrPreferences.max_history_entries, gtranslator_preferences_dialog_changed);
+		GtrPreferences.max_history_entries, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	
 	check_recent_files=gtranslator_utils_attach_toggle_with_label(fifth_page, 1,
 		_("Check recent files before showing in recent files' list"),
-		GtrPreferences.check_recent_file, gtranslator_preferences_dialog_changed);
+		GtrPreferences.check_recent_file, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	instant_spell_checking=gtranslator_utils_attach_toggle_with_label(fifth_page, 2,
 		_("Instant spell checking"),
-		GtrPreferences.instant_spell_check, gtranslator_preferences_dialog_changed);
+		GtrPreferences.instant_spell_check, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	
 	use_own_dict = gtk_check_button_new_with_label(_("Use special dictionary:"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(use_own_dict),
@@ -251,10 +240,10 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	gtk_widget_set_sensitive(GTK_WIDGET(dictionary_file), GtrPreferences.use_own_dict);
 	gtk_table_attach_defaults(GTK_TABLE(fifth_page), dictionary_file, 1, 2, 3, 4);
 	
-	gtk_signal_connect(GTK_OBJECT(use_own_dict), "toggled",
-			   GTK_SIGNAL_FUNC(toggle_sensitive), dictionary_file);
-	gtk_signal_connect(GTK_OBJECT(dictionary_file), "changed",
-			   GTK_SIGNAL_FUNC(gtranslator_preferences_dialog_changed), NULL);
+	g_signal_connect(G_OBJECT(use_own_dict), "toggled",
+			 G_CALLBACK(toggle_sensitive), dictionary_file);
+	g_signal_connect(G_OBJECT(dictionary_file), "changed",
+			 G_CALLBACK(gtranslator_preferences_dialog_changed), NULL);
 	
 	/*
 	 * The sixth page with the special font/color stuff.
@@ -264,31 +253,31 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	scheme_file=gtranslator_utils_attach_combo_with_label(sixth_page, 0,
 		_("Syntax color scheme to use:"), colorschemes, old_colorscheme,
 		FALSE,
-		gtranslator_preferences_dialog_changed, NULL);
+		G_CALLBACK(gtranslator_preferences_dialog_changed), NULL);
 	 
 	own_fonts=gtranslator_utils_attach_toggle_with_label(sixth_page, 1,
 		_("Apply own fonts:"),
-		GtrPreferences.use_own_fonts, gtranslator_preferences_dialog_changed);
+		GtrPreferences.use_own_fonts, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	msgid_font=gtranslator_utils_attach_font_with_label(sixth_page, 2,
 		_("Original text font:"), _("gtranslator -- font selection/msgid font"),
-		GtrPreferences.msgid_font, gtranslator_preferences_dialog_changed);
+		GtrPreferences.msgid_font, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	
 	msgstr_font=gtranslator_utils_attach_font_with_label(sixth_page, 3,
 		_("Translation font:"), _("gtranslator -- font selection/msgstr font"),
-		GtrPreferences.msgstr_font, gtranslator_preferences_dialog_changed);
+		GtrPreferences.msgstr_font, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	own_colors=gtranslator_utils_attach_toggle_with_label(sixth_page, 4,
 		_("Apply own colors:"),
-		GtrPreferences.use_own_colors, gtranslator_preferences_dialog_changed);
+		GtrPreferences.use_own_colors, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	foreground=gtranslator_utils_attach_color_with_label(sixth_page, 5,
 		_("Foreground color:"), _("gtranslator -- foreground color"),
-		COLOR_FG, gtranslator_preferences_dialog_changed);
+		COLOR_FG, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	background=gtranslator_utils_attach_color_with_label(sixth_page, 6,
 		_("Background color:"), _("gtranslator -- background color"),
-		COLOR_BG, gtranslator_preferences_dialog_changed);
+		COLOR_BG, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	/*
 	 * The seventh page of the prefs-box: autosaving options.
@@ -303,10 +292,10 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	gtk_widget_set_sensitive(GTK_WIDGET(autosave_timeout), GtrPreferences.autosave);
 	gtk_table_attach_defaults(GTK_TABLE(seventh_page), autosave_timeout, 1, 2, 0, 1);
 	
-	gtk_signal_connect(GTK_OBJECT(autosave), "toggled",
-			   GTK_SIGNAL_FUNC(toggle_sensitive), autosave_timeout);
-	gtk_signal_connect(GTK_OBJECT(autosave_timeout), "changed",
-			   GTK_SIGNAL_FUNC(gtranslator_preferences_dialog_changed), NULL);
+	g_signal_connect(G_OBJECT(autosave), "toggled",
+			 G_CALLBACK(toggle_sensitive), autosave_timeout);
+	g_signal_connect(G_OBJECT(autosave_timeout), "changed",
+			 G_CALLBACK(gtranslator_preferences_dialog_changed), NULL);
 
 	autosave_with_suffix = gtk_check_button_new_with_label(_("Append a suffix to automatically saved files:"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(autosave_with_suffix),
@@ -319,37 +308,37 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	gtk_widget_set_sensitive(GTK_WIDGET(autosave_suffix), GtrPreferences.autosave_with_suffix);
 	gtk_table_attach_defaults(GTK_TABLE(seventh_page), autosave_suffix, 1, 2, 1, 2);
 	
-	gtk_signal_connect(GTK_OBJECT(autosave_with_suffix), "toggled",
-			   GTK_SIGNAL_FUNC(toggle_sensitive), autosave_suffix);
-	gtk_signal_connect(GTK_OBJECT(autosave_suffix), "changed",
-			   GTK_SIGNAL_FUNC(gtranslator_preferences_dialog_changed), NULL);
+	g_signal_connect(G_OBJECT(autosave_with_suffix), "toggled",
+			 G_CALLBACK(toggle_sensitive), autosave_suffix);
+	g_signal_connect(G_OBJECT(autosave_suffix), "changed",
+			 G_CALLBACK(gtranslator_preferences_dialog_changed), NULL);
 
 	/*
 	 * The eighth page with the messages table concerning settings.
 	 */
 	show_messages_table=gtranslator_utils_attach_toggle_with_label(eighth_page, 0,
 		_("Show the messages table (requires gtranslator restart)"),
-		GtrPreferences.show_messages_table, gtranslator_preferences_dialog_changed);
+		GtrPreferences.show_messages_table, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	collapse_translated_entries=gtranslator_utils_attach_toggle_with_label(eighth_page, 1,
 		_("Collapse translated entries by default"),
-		GtrPreferences.collapse_translated, gtranslator_preferences_dialog_changed);
+		GtrPreferences.collapse_translated, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	use_own_mt_colors=gtranslator_utils_attach_toggle_with_label(eighth_page, 2,
 		_("Use own colors for the messages table groups"),
-		GtrPreferences.use_own_mt_colors, gtranslator_preferences_dialog_changed);
+		GtrPreferences.use_own_mt_colors, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	mt_untranslated=gtranslator_utils_attach_color_with_label(eighth_page, 3,
 		_("Untranslated entries color:"), _("gtranslator -- untranslated entries' color"),
-		COLOR_MESSAGES_TABLE_UNTRANSLATED, gtranslator_preferences_dialog_changed);
+		COLOR_MESSAGES_TABLE_UNTRANSLATED, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	mt_fuzzy=gtranslator_utils_attach_color_with_label(eighth_page, 4,
 		_("Fuzzy entries color:"), _("gtranslator -- fuzzy entries' color"),
-		COLOR_MESSAGES_TABLE_FUZZY, gtranslator_preferences_dialog_changed);
+		COLOR_MESSAGES_TABLE_FUZZY, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	mt_translated=gtranslator_utils_attach_color_with_label(eighth_page, 5,
 		_("Translated entries color:"), _("gtranslator -- translated entries' color"),
-		COLOR_MESSAGES_TABLE_TRANSLATED, gtranslator_preferences_dialog_changed);
+		COLOR_MESSAGES_TABLE_TRANSLATED, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	/*
 	 * Learn buffer/auto translation options go now into their own prefs page ,-)
@@ -357,11 +346,11 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 	use_learn_buffer =
 	    gtranslator_utils_attach_toggle_with_label(ninth_page, 0,
 	    	_("Also query the personal learn buffer while autotranslating untranslated messages"),
-		GtrPreferences.use_learn_buffer, gtranslator_preferences_dialog_changed);
+		GtrPreferences.use_learn_buffer, G_CALLBACK(gtranslator_preferences_dialog_changed));
     	auto_learn =
 	    gtranslator_utils_attach_toggle_with_label(ninth_page, 1,
 	    	_("Automatically learn a newly translated message"),
-		GtrPreferences.auto_learn, gtranslator_preferences_dialog_changed);
+		GtrPreferences.auto_learn, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	fuzzy_matching=gtranslator_utils_attach_toggle_with_label(ninth_page,
 		/*
 		 * Translators: With "fuzzy" I mean a more enhanced (and more
@@ -369,25 +358,22 @@ void gtranslator_preferences_dialog_create(GtkWidget  *widget, gpointer useless)
 		 *   for a original string.
 		 */
 		2, _("Use \"fuzzy\" matching routines for the learn buffer queries"),
-		GtrPreferences.fuzzy_matching, gtranslator_preferences_dialog_changed);
+		GtrPreferences.fuzzy_matching, G_CALLBACK(gtranslator_preferences_dialog_changed));
 	min_match_percentage=gtranslator_utils_attach_spin_with_label(ninth_page,
 		3, _("Minimal required similarity percentage for fuzzy queries"),
-		25, 100, GtrPreferences.min_match_percentage, gtranslator_preferences_dialog_changed);
+		25, 100, GtrPreferences.min_match_percentage, G_CALLBACK(gtranslator_preferences_dialog_changed));
 
 	/*
 	 * Connect the signals to the preferences box.
 	 */
-	gtk_signal_connect(GTK_OBJECT(prefs), "apply",
-			   GTK_SIGNAL_FUNC(gtranslator_preferences_dialog_apply), NULL);
-	gtk_signal_connect(GTK_OBJECT(prefs), "help",
-			   GTK_SIGNAL_FUNC(gtranslator_preferences_dialog_help), NULL);
-	gtk_signal_connect(GTK_OBJECT(prefs), "close",
-			   GTK_SIGNAL_FUNC(gtranslator_utils_language_lists_free), NULL);
+	g_signal_connect(G_OBJECT(prefs), "apply",
+			 G_CALLBACK(gtranslator_preferences_dialog_apply), NULL);
+	g_signal_connect(G_OBJECT(prefs), "help",
+			 G_CALLBACK(gtranslator_preferences_dialog_help), NULL);
+	g_signal_connect(G_OBJECT(prefs), "close",
+			 G_CALLBACK(gtranslator_utils_language_lists_free), NULL);
 
-	gtk_window_set_wmclass(GTK_WINDOW(prefs), "gtranslator -- prefs",
-		"gtranslator");
-	gtk_window_set_position(GTK_WINDOW(prefs), GTK_WIN_POS_CENTER);
-	gtk_widget_show_all(prefs);
+	gtranslator_dialog_show(&prefs, "gtranslator -- prefs");
 }
 
 /*
@@ -464,7 +450,6 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	update(gtranslator_translator->language->bits, GTK_COMBO(encoding)->entry);
 	update(GtrPreferences.dictionary, dictionary_file);
 	update(GtrPreferences.autosave_suffix, autosave_suffix);
-	update(GtrPreferences.compile_output_dir, compile_output_dir);
 #undef update
 #define if_active(widget) \
 	gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))
@@ -475,7 +460,6 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	GtrPreferences.dot_char = if_active(use_dot_char);
 	GtrPreferences.update_function = if_active(use_update_function);
 	GtrPreferences.rambo_function = if_active(rambo_function);
-	GtrPreferences.popup_menu = if_active(enable_popup_menu);
 	GtrPreferences.sweep_compile_file = if_active(sweep_compile_file);
 	GtrPreferences.show_comment = if_active(show_comment);
 	GtrPreferences.show_messages_table = if_active(show_messages_table);
@@ -488,10 +472,8 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	GtrPreferences.use_own_dict = if_active(use_own_dict);
 	GtrPreferences.use_learn_buffer = if_active(use_learn_buffer);
 	GtrPreferences.fuzzy_matching = if_active(fuzzy_matching);
-	GtrPreferences.load_backends = if_active(load_backends);
 	GtrPreferences.auto_learn = if_active(auto_learn);
 	GtrPreferences.keep_obsolete = if_active(keep_obsolete);
-	GtrPreferences.check_formats = if_active(check_formats);
 	GtrPreferences.autosave = if_active(autosave);
 	GtrPreferences.autosave_with_suffix = if_active(autosave_with_suffix);
 #undef if_active
@@ -509,8 +491,6 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 			min_match_percentage));
 	
 	gtranslator_config_set_string("dict/file", GtrPreferences.dictionary);
-	gtranslator_config_set_string("misc/compile_output_dir", GtrPreferences.compile_output_dir);
-
 	gtranslator_config_set_string("informations/autosave_suffix", 
 		GtrPreferences.autosave_suffix);
 	
@@ -564,13 +544,13 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 		 *  ~/.gtranslator/colorschemes directory, try the global 
 		 *   colorschemes directory.
 		 */
-		if(!g_file_exists(GtrPreferences.scheme))
+		if(!g_file_test(GtrPreferences.scheme, G_FILE_TEST_EXISTS))
 		{
 			GtrPreferences.scheme=g_strdup_printf("%s/%s.xml", 
 				SCHEMESDIR, selected_scheme_file);
 		}
 	    
-		if(g_file_exists(GtrPreferences.scheme))
+		if(g_file_test(GtrPreferences.scheme, G_FILE_TEST_EXISTS))
 		{
 			/*
 			 * Free the old used colorscheme.
@@ -602,8 +582,8 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 	gtranslator_color_values_set(GNOME_COLOR_PICKER(mt_translated), 
 		COLOR_MESSAGES_TABLE_TRANSLATED);
 
-	gtranslator_set_style(text_box, 0);
-	gtranslator_set_style(trans_box, 1);
+	gtranslator_set_style(GTK_WIDGET(text_box), 0);
+	gtranslator_set_style(GTK_WIDGET(trans_box), 1);
 
 	gtranslator_config_set_bool("toggles/save_geometry", GtrPreferences.save_geometry);
 	gtranslator_config_set_bool("toggles/warn_if_fuzzy", GtrPreferences.warn_if_fuzzy);
@@ -615,16 +595,12 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 			      GtrPreferences.update_function);
 	gtranslator_config_set_bool("toggles/sweep_compile_file",
 			      GtrPreferences.sweep_compile_file);
-	gtranslator_config_set_bool("toggles/enable_popup_menu",
-			      GtrPreferences.popup_menu);
 	gtranslator_config_set_bool("toggles/show_comment",
 			      GtrPreferences.show_comment);
 	gtranslator_config_set_bool("toggles/rambo_function",
 			      GtrPreferences.rambo_function);
 	gtranslator_config_set_bool("toggles/check_recent_files",
 			      GtrPreferences.check_recent_file);
-	gtranslator_config_set_bool("toggles/check_formats",
-			      GtrPreferences.check_formats);
 	gtranslator_config_set_bool("toggles/highlight",
 			      GtrPreferences.highlight);
 	gtranslator_config_set_bool("toggles/instant_spell_check",
@@ -641,8 +617,6 @@ static void gtranslator_preferences_dialog_apply(GtkWidget  * box, gint page_num
 			      GtrPreferences.use_learn_buffer);
 	gtranslator_config_set_bool("toggles/fuzzy_matching",
 			      GtrPreferences.fuzzy_matching);
-	gtranslator_config_set_bool("toggles/load_backends",
-			      GtrPreferences.load_backends);
 	gtranslator_config_set_bool("toggles/auto_learn",
 			      GtrPreferences.auto_learn);
 	gtranslator_config_set_bool("toggles/show_messages_table",
@@ -683,7 +657,7 @@ to work in ways you find comfortable and productive."));
 static void gtranslator_preferences_dialog_changed(GtkWidget  * widget, gpointer flag)
 {
 	gint c = 0;
-	gchar *current;
+	G_CONST_RETURN gchar *current;
 	gnome_property_box_changed(GNOME_PROPERTY_BOX(prefs));
 #define set_text(widget,field) \
 	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(widget)->entry),\
@@ -746,14 +720,7 @@ void gtranslator_preferences_read(void)
 	
 	GtrPreferences.dictionary = gtranslator_config_get_string("dict/file");
 	GtrPreferences.scheme =  gtranslator_config_get_string("scheme/filename");
-
-	GtrPreferences.compile_output_dir = gtranslator_config_get_string("misc/compile_output_dir");
-
-	if(!GtrPreferences.compile_output_dir || !g_file_test(GtrPreferences.compile_output_dir, G_FILE_TEST_ISDIR))
-	{
-		GtrPreferences.compile_output_dir=g_strdup(".");
-	}
-
+	
 	GtrPreferences.autosave =
 		gtranslator_config_get_bool("toggles/autosave");
 	GtrPreferences.autosave_timeout = 
@@ -790,8 +757,6 @@ void gtranslator_preferences_read(void)
 		gtranslator_config_get_bool("toggles/set_non_fuzzy_if_changed"); 
 	GtrPreferences.warn_if_fuzzy =
 		gtranslator_config_get_bool("toggles/warn_if_fuzzy");
-	GtrPreferences.popup_menu =
-		gtranslator_config_get_bool("toggles/enable_popup_menu");
 	GtrPreferences.update_function =
 		gtranslator_config_get_bool("toggles/use_update_function");
 	GtrPreferences.sweep_compile_file =
@@ -817,12 +782,8 @@ void gtranslator_preferences_read(void)
 		"toggles/use_learn_buffer");
 	GtrPreferences.fuzzy_matching = gtranslator_config_get_bool(
 		"toggles/fuzzy_matching");
-	GtrPreferences.load_backends = gtranslator_config_get_bool(
-		"toggles/load_backends");
 	GtrPreferences.auto_learn = gtranslator_config_get_bool(
 		"toggles/auto_learn");
-	GtrPreferences.check_formats = gtranslator_config_get_bool(
-		"toggles/check_formats");
 	GtrPreferences.highlight = gtranslator_config_get_bool(
 		"toggles/highlight");
 	GtrPreferences.match_case = gtranslator_config_get_bool(
@@ -847,8 +808,8 @@ void gtranslator_preferences_read(void)
 		/*
 		 * Set the own specs for colors and for the font.
 		 */
-		gtranslator_set_style(text_box, 0);
-		gtranslator_set_style(trans_box, 1);
+		gtranslator_set_style(GTK_WIDGET(text_box), 0);
+		gtranslator_set_style(GTK_WIDGET(trans_box), 1);
 	}
 }
 
@@ -858,7 +819,6 @@ void gtranslator_preferences_read(void)
 void gtranslator_preferences_free()
 {
 	GTR_FREE(GtrPreferences.autosave_suffix);
-	GTR_FREE(GtrPreferences.compile_output_dir);
 	GTR_FREE(GtrPreferences.spell_command);
 	GTR_FREE(GtrPreferences.dictionary);
 	GTR_FREE(GtrPreferences.msgid_font);
