@@ -40,13 +40,11 @@ struct {
 	guint match_case		: 1;
 	guint find_in			: 3;
 	guint use_learn_buffer		: 1;
-	guint load_backends		: 1;
 	guint fuzzy_matching		: 1;
 	guint auto_learn		: 1;
 	guint show_messages_table	: 1;
 	guint show_comment		: 1;
 	guint collapse_translated	: 1;
-	guint check_formats		: 1;
 
 	/*
 	 * Special options, taken by value in the prefs-box.
@@ -56,7 +54,6 @@ struct {
 	guint rambo_function		: 1;
 	guint highlight			: 1;
 	guint dot_char			: 1;
-	guint popup_menu		: 1;
 	guint check_recent_file		: 1;
 	guint use_own_fonts		: 1;
 	guint use_own_colors		: 1;
@@ -78,8 +75,7 @@ struct {
 	/*
 	 * User-specified strings.
 	 */
-	gchar *autosave_suffix;
-	gchar *compile_output_dir;
+	gchar *autosave_suffix; 
 	gchar *spell_command;
 	gchar *dictionary;
 	gchar *msgid_font;
