@@ -1,5 +1,5 @@
 /*
- * (C) 2001-2002 		Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001 		Fatih Demir <kabalak@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -58,24 +58,17 @@ void gtranslator_preferences_init_default_values()
 		gtranslator_config_set_bool("toggles/sweep_compile_file", FALSE);
 		gtranslator_config_set_bool("toggles/use_learn_buffer", TRUE);
 		gtranslator_config_set_bool("toggles/fuzzy_matching", FALSE);
-		gtranslator_config_set_bool("toggles/load_backends", TRUE);
 		gtranslator_config_set_bool("toggles/highlight", TRUE);
 
-		/*
-		 * And this should be kept FALSE for now -- maybe it'll get
-		 *  also TRUE in future when this works more sanely :-)
-		 */
-		gtranslator_config_set_bool("toggles/check_formats", FALSE);
-		
 		/*
 		 * GUI related default values.
 		 */
 		gtranslator_config_set_bool("toggles/save_geometry", TRUE);
 		gtranslator_config_set_bool("toggles/use_dot_char", TRUE);
+		gtranslator_config_set_bool("toggles/show_sidebar", TRUE);
 		gtranslator_config_set_bool("toggles/show_messages_table", TRUE);
 		gtranslator_config_set_bool("toggles/show_comment", TRUE);
 		gtranslator_config_set_bool("toggles/collapse_translated_entries", TRUE);
-		gtranslator_config_set_bool("toggles/enable_popup_menu", TRUE);
 		gtranslator_config_set_bool("toggles/use_update_function", TRUE);
 		gtranslator_config_set_bool("toggles/rambo_function", FALSE);
 		
@@ -97,13 +90,10 @@ void gtranslator_preferences_init_default_values()
 		/*
 		 * Set the pane positions to sane values.
 		 */
-		gtranslator_config_set_int("interface/table_pane_position", 200);
-
-		/*
-		 * Per default we're putting our compiled files into "." (ergo,
-		 *  the current directory).
-		 */
-		gtranslator_config_set_string("misc/compile_output_dir", ".");
+		gtranslator_config_set_int("interface/sidebar_pane_position",
+			90); 
+		gtranslator_config_set_int("interface/table_pane_position",
+			200); 
 
 		/*
 		 * We do want maximally 10 history entries per default.
@@ -128,7 +118,7 @@ void gtranslator_preferences_init_default_values()
 		/*
 		 * Set the default colorscheme name + filename.
 		 */
-		gtranslator_config_set_string("scheme/name", "default.xml");
+		gtranslator_config_set_string("scheme/name", "default");
 		gtranslator_config_set_string("scheme/filename", SCHEMESDIR
 			"/default.xml");
 
@@ -142,6 +132,7 @@ void gtranslator_preferences_init_default_values()
 	GTR_FREE(date);
 }
 
+
 /*
  * Setup the default colors.
  */ 
