@@ -34,9 +34,11 @@
 
 #include <gtk/gtk.h>
 
+static GString *gtranslator_parse_syntax(GtkTextBuffer *textbuffer);
+
 static gboolean back_match(const gchar *msg, gchar *str, gint pos);
 void gtranslator_update_highlighted(
-		GtkEditable *textwidget,
+		GtkTextBuffer *textbuffer,
 		gpointer userdata );
 
 /*
@@ -89,144 +91,158 @@ static void text_data_free(gpointer data)
  * This function initializes the syntax parser for text widget.
  * The highlighting info will be inside string, so ~250 colors possible
  */
-void gtranslator_syntax_init(GtkEditable *textwidget)
+void gtranslator_syntax_init(GtkTextView *textview)
 {
 	GString *n;
+	GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(textview);
+	g_return_if_fail(textbuffer != NULL);
 	
-	g_return_if_fail(textwidget!=NULL);
-	
+#ifdef NOT_PORTED
 	n = g_string_new("");
 	
-	gtk_object_set_data_full(
-		GTK_OBJECT(textwidget), 
+	g_object_set_data_full(
+		G_OBJECT(textbuffer), 
 		"textdata", 
 		n,
 		text_data_free);
 	
-	gtk_signal_connect(GTK_OBJECT(textwidget), "insert_text",
-			   GTK_SIGNAL_FUNC(gtranslator_insert_highlighted), NULL);
-	gtk_signal_connect(GTK_OBJECT(textwidget), "delete_text",
-			   GTK_SIGNAL_FUNC(gtranslator_delete_highlighted), NULL);
-	gtk_signal_connect(GTK_OBJECT(textwidget), "changed",
-			   GTK_SIGNAL_FUNC(gtranslator_update_highlighted), NULL);
+	g_signal_connect(G_OBJECT(textbuffer), "insert-text",
+			 G_CALLBACK(gtranslator_insert_highlighted), NULL);
+	g_signal_connect(G_OBJECT(textbuffer), "delete-range",
+			 G_CALLBACK(gtranslator_delete_highlighted), NULL);
+	g_signal_connect(G_OBJECT(textbuffer), "changed",
+			 G_CALLBACK(gtranslator_update_highlighted), NULL);
+#endif //NOT_PORTED
 }
 
 void gtranslator_update_highlighted(
-		GtkEditable *textwidget,
+		GtkTextBuffer *textbuffer,
 		gpointer userdata )
 {
 	GString *newdata, *olddata;
 	gint i,j;
+	GtkTextIter I, J;
 	guint point;
 	gchar type;
-
-	gtk_text_freeze( GTK_TEXT( textwidget ) );
-
-	olddata = (GString *)gtk_object_get_data(
-		GTK_OBJECT(textwidget), 
+	//	gtk_text_freeze( GTK_TEXT( textwidget ) );
+	
+	olddata = (GString *)g_object_get_data(
+		G_OBJECT(textbuffer), 
 		"textdata");
-		
-	point = gtk_text_get_point(GTK_TEXT(textwidget));
+	newdata = olddata;
+#ifdef NOT_PORTED		
+	//	point = gtk_text_get_point(GTK_TEXT(textwidget));
 	/* Parse highlighting */
-	newdata = gtranslator_parse_syntax(GTK_EDITABLE(textwidget));
+	newdata = gtranslator_parse_syntax(textbuffer);
+
+	gtk_text_buffer_get_start_iter(textbuffer, &I);
+	gtk_text_buffer_get_start_iter(textbuffer, &J);
 	/* Update highlighting */
 	for(i=0; i<newdata->len;)
 	{
+	  gtk_text_iter_forward_char(&I);
+	  
 		if((type = *(newdata->str + i)) != 
 			*(olddata->str + i))
 		{
-			static gchar
-				*c;
+		        static gchar   *c;
+
+			gtk_text_iter_set_offset(&J, i);
 			for( j=0; newdata->str[i] == newdata->str[i+j]; j++ )
 				if( newdata->len <= (i+j) )
-					break;	
-			c = gtk_editable_get_chars(
-				GTK_EDITABLE(textwidget), i, i+j);
-			gtk_text_set_point(GTK_TEXT(textwidget), i);
-			gtk_text_forward_delete(GTK_TEXT(textwidget), j);
-			gtk_text_insert(
-				GTK_TEXT(textwidget),
-				NULL,
-				gtranslator_get_color_from_type((gint)type),
-				gtranslator_get_color_from_type(COLOR_TEXT_BG),
-				c, j);
+					break;
+			gtk_text_iter_forward_char(&J);
+			c = gtk_text_iter_get_text(&I, &J);
+			//gtk_text_set_point(GTK_TEXT(textwidget), i);
+			//gtk_text_forward_delete(GTK_TEXT(textwidget), j);
+			//gtk_text_insert(
+			//	GTK_TEXT(textwidget),
+			//	NULL,
+			//	gtranslator_get_color_from_type((gint)type),
+			//	gtranslator_get_color_from_type(COLOR_TEXT_BG),
+			//	c, j);
 			g_free(c);
 			i += j;
 		}
 		else
 			i++;
 	}
+#endif
+	gtk_text_buffer_insert_at_cursor(textbuffer, 
+					 newdata->str, newdata->len);
 	/* Free olddata and register newdata */
-	gtk_object_set_data_full(
-		GTK_OBJECT(textwidget), 
+	g_object_set_data_full(
+		G_OBJECT(textbuffer), 
 		"textdata", 
 		newdata,
 		text_data_free);
 
 	/* gtk_text_set_point( GTK_TEXT( textwidget ), point ); */
 
-	gtk_text_thaw( GTK_TEXT( textwidget ) );
-	gtk_editable_set_position( GTK_EDITABLE( textwidget), point );
+	//	gtk_text_thaw( GTK_TEXT( textwidget ) );
+	//gtk_editable_set_position( GTK_EDITABLE( textwidget), point );
 }
 
 /*
  * This function will update highlightion information for text.
  */
 void gtranslator_insert_highlighted(
-		GtkEditable *textwidget,
+		GtkTextBuffer *textbuffer,
+		GtkTextIter* pos,
 		gchar	*text,
 		gint	addlen,
-		gint	*pos,
 		gpointer userdata)
 {
 	GString *olddata;
 	gint i;
-	
-	g_return_if_fail(textwidget != NULL);
-	g_return_if_fail(text!=NULL);
 
-	olddata = (GString *)gtk_object_get_data(
-		GTK_OBJECT(textwidget), 
+	g_return_if_fail(textbuffer != NULL);
+	g_return_if_fail(text!=NULL);
+	
+	olddata = (GString *)g_object_get_data(
+		G_OBJECT(textbuffer), 
 		"textdata");
-	for(i=0; i<addlen; i++)
+/*	for(i=0; i<addlen; i++)
 	{
 		olddata = g_string_insert_c(olddata, *pos, COLOR_NONE);
-	}
+	}*/
 }
 
 /*
  * This function will delete text and rehighlight.
  */
 void gtranslator_delete_highlighted(
-		GtkEditable *textwidget,
-		gint	startpos,
-		gint	endpos,
+		GtkTextBuffer *textbuffer,
+		GtkTextIter *start,
+		GtkTextIter *end,
 		gpointer	userdata)
 {
 	GString *olddata;
 	gint len;
-	
-	g_return_if_fail(textwidget != NULL);
-	g_return_if_fail(startpos >= 0);
 
-	if(endpos < 0){
-		len = gtk_text_get_length(GTK_TEXT(textwidget))-startpos;
-	}
-	else{
-		len = endpos - startpos;
+	g_return_if_fail(textbuffer != NULL);
+
+/*	if(endpos < 0){
+		len = gtk_text_buffer_get_char_count(textbuffer) - startpos;
 	}
+	else {*/
+		len = gtk_text_iter_get_offset(end)
+			- gtk_text_iter_get_offset(start);
+//	}
 	
-	olddata = (GString *)gtk_object_get_data(
-		GTK_OBJECT(textwidget), 
+	olddata = (GString *)g_object_get_data(
+		G_OBJECT(textbuffer), 
 		"textdata");
-	olddata = g_string_erase( olddata, startpos, len);
+	
+	olddata = g_string_erase( olddata, gtk_text_iter_get_offset(start), len);
 }
 
-GString *gtranslator_parse_syntax(GtkEditable *textwidget)
+static GString *gtranslator_parse_syntax(GtkTextBuffer *textbuffer)
 {
 	GString *string;
 	gboolean aInserted;
 	gchar specialchar, *msg;
+	GtkTextIter start, end;
 	gint cp;
 	gint z=0;
 
@@ -241,12 +257,11 @@ GString *gtranslator_parse_syntax(GtkEditable *textwidget)
 
 	extern gboolean nosyntax;
 	
-	g_return_val_if_fail(textwidget!=NULL, NULL);
-
-	msg = gtk_editable_get_chars(
-		GTK_EDITABLE(textwidget),
-		0, -1);
+	g_return_val_if_fail(textbuffer!=NULL, NULL);
 
+	gtk_text_buffer_get_bounds(textbuffer, &start, &end);
+	msg = gtk_text_buffer_get_text(textbuffer, &start, &end, FALSE);
+	       
 	if(GtrPreferences.dot_char)
 	{
 		specialchar=gtranslator_runtime_config->special_char;
@@ -489,26 +504,34 @@ GString *gtranslator_parse_syntax(GtkEditable *textwidget)
 	return string;
 }
 
-void gtranslator_insert_text(GtkText *editable, const gchar *text)
+// XXX fix it
+void gtranslator_insert_text(GtkTextView *textview, const gchar *text)
 {
-	gint pos=0;
-
+	GtkTextIter start, end;
+	GtkTextBuffer *editable = gtk_text_view_get_buffer(textview);
+	
+//	gtk_text_buffer_get_bounds (editable, &start, &end);
+	if (text)
+		gtk_text_buffer_set_text (editable, text, -1);
+#ifdef NOT_PORTED	
 	/* First, delete old contents */
-	gtk_signal_emit_by_name(
-		GTK_OBJECT(editable),
-		"delete-text",
-		0,
-		-1);
+	g_signal_emit_by_name(
+		G_OBJECT(editable),
+		"delete-range",
+		&start,
+		&end);
 	if (!text)
 		return;
 	/* Second add new context */
-	gtk_signal_emit_by_name(
-		GTK_OBJECT(editable),
+	g_signal_emit_by_name(
+		G_OBJECT(editable),
 		"insert-text",
+		&start,
 		text,
-		strlen(text),
-		&pos);
-	gtk_signal_emit_by_name(
-		GTK_OBJECT(editable),
+		strlen(text));
+	g_signal_emit_by_name(
+		G_OBJECT(editable),
 		"changed");
+#endif //NOT_PORTED
 }
+
