@@ -1,5 +1,6 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
+ * 			Thomas Ziehmer <thomas@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +23,6 @@
 #endif
 
 #include "comment.h"
-#include "convert.h"
 #include "syntax.h"
 #include "utf8.h"
 #include "utils.h"
@@ -51,14 +51,24 @@ gboolean gtranslator_utf8_po_file_is_utf8()
 void gtranslator_utf8_convert_message_to_utf8(GtrMsg *msg)
 {
 	gchar *msgstr;
+	gchar *msgid;
 
 	g_return_if_fail(msg!=NULL);
 
-	msgstr=(msg)->msgstr;
-	(msg)->msgstr=gtranslator_convert_string_to_utf8(msgstr,
-		po->header->charset);
-	
-	GTR_FREE(msgstr);
+	if (msg->msgstr) {
+		msgstr=msg->msgstr;
+		msg->msgstr=g_convert(msgstr, -1, 
+	                	      "UTF-8", po->header->charset, 
+	        	              NULL, NULL, NULL);
+		g_free(msgstr);
+	}
+
+	msgid=msg->msgid;
+	msg->msgid=g_convert(msgid, -1, 
+	                      "UTF-8", po->header->charset, 
+	                      NULL, NULL, NULL);
+	g_free(msgid);
+
 }
 
 /*
@@ -70,11 +80,11 @@ void gtranslator_utf8_convert_message_from_utf8(GtrMsg *msg)
 
 	g_return_if_fail(msg!=NULL);
 
-	msgstr=(msg)->msgstr;
-	(msg)->msgstr=gtranslator_convert_string_from_utf8(msgstr,
-		po->header->charset);
-	
-	GTR_FREE(msgstr);
+	msgstr=msg->msgstr;
+	msg->msgstr=g_convert(msgstr, -1, 
+	                      po->header->charset, "UTF-8",
+	                      NULL, NULL, NULL);
+	g_free(msgstr);
 }
 
 /*
@@ -93,11 +103,11 @@ void gtranslator_utf8_convert_po_to_utf8(void)
 	/*
 	 * Convert the author name to UTF-8.
 	 */
-	author=gtranslator_convert_string_to_utf8(po->header->translator, po->header->charset);
-	GTR_FREE(po->header->translator);
-
-	po->header->translator=g_strdup(author);
-	GTR_FREE(author);
+	author=g_convert(po->header->translator, -1, 
+	                 po->header->charset, "UTF-8",
+	                 NULL, NULL, NULL);
+	g_free(po->header->translator);
+	po->header->translator=author;
 
 	/*
 	 * Convert the header comment to a GtrComment and get the UTF-8 version of it.
@@ -136,114 +146,13 @@ void gtranslator_utf8_convert_po_from_utf8(void)
 }
 
 /*
- * Return the plain string from the given UTF-8 string.
+ * Simply saves some typing...
  */
-gchar *gtranslator_utf8_get_plain_string(gchar **string)
+gchar *gtranslator_utf8_convert_to_utf8(const gchar *str)
 {
-	gchar *plain_string;
+	g_return_val_if_fail(str!=NULL, NULL);
+	g_return_val_if_fail(GTR_HEADER(po->header)!=NULL, NULL);
+	g_return_val_if_fail(GTR_HEADER(po->header->charset)!=NULL, NULL);
 
-	g_return_val_if_fail(*string!=NULL, NULL);
-
-	plain_string=gtranslator_convert_string_from_utf8(*string,
-		po->locale_charset);
-
-	return plain_string;
-}
-
-/*
- * Return a pure UTF-8 string back.
- */
-gchar *gtranslator_utf8_get_utf8_string(gchar **string)
-{
-	gchar 	*utf8_string;
-	
-	g_return_val_if_fail(*string!=NULL, NULL);
-
-	utf8_string=gtranslator_convert_string_to_utf8(*string,
-		po->locale_charset);
-
-	return utf8_string;
-}
-
-/*
- * Return the plain msgstr (uses the function above).
- */
-gchar *gtranslator_utf8_get_plain_msgstr(GtrMsg **message)
-{
-	g_return_val_if_fail(GTR_MSG(*message)->msgstr!=NULL, NULL);
-
-	return (gtranslator_utf8_get_plain_string(&GTR_MSG(*message)->msgstr));
-}
-
-/*
- * Convenience functions to get/set the "plain" content of a GtkEntry
- *  in UTF-8 form.
- */
-gchar *gtranslator_utf8_get_gtk_entry_as_utf8_string(GtkWidget *entry)
-{
-	gchar *entry_content;
-	
-	g_return_val_if_fail(GTK_WIDGET(entry)!=NULL, NULL);
-
-	entry_content=gtk_entry_get_text(GTK_ENTRY(entry));
-	g_return_val_if_fail(entry_content!=NULL, NULL);
-
-	return (gtranslator_utf8_get_utf8_string(&entry_content));
-}
-
-void gtranslator_utf8_set_gtk_entry_from_utf8_string(GtkWidget *entry,
-	const gchar *utf8_string)
-{
-	gchar *plain_string;
-	gchar *convert_me;
-	
-	g_return_if_fail(GTK_WIDGET(entry)!=NULL);
-	g_return_if_fail(utf8_string!=NULL);
-	
-	convert_me=g_strdup(utf8_string);
-
-	plain_string=gtranslator_utf8_get_plain_string(&convert_me);
-	g_return_if_fail(plain_string!=NULL);
-	
-	GTR_FREE(convert_me);
-
-	gtk_entry_set_text(GTK_ENTRY(entry), plain_string);
-}
-
-/*
- * Convenience function to get/set the normal content of a GtkText in UTF-8
- *  form.
- */
-gchar *gtranslator_utf8_get_gtk_text_as_utf8_string(GtkWidget *text)
-{
-	gchar *text_content;
-	
-	g_return_val_if_fail(GTK_WIDGET(text)!=NULL, NULL);
-
-	text_content=gtk_editable_get_chars(GTK_EDITABLE(text), 0, -1);
-	g_return_val_if_fail(text_content!=NULL, NULL);
-
-	return (gtranslator_utf8_get_utf8_string(&text_content));
-}
-
-void gtranslator_utf8_set_gtk_text_from_utf8_string(GtkWidget *text,
-	const gchar *utf8_string)
-{
-	gchar *plain_string;
-	gchar *convert_me;
-
-	g_return_if_fail(GTK_WIDGET(text)!=NULL);
-	g_return_if_fail(utf8_string!=NULL);
-
-	convert_me=g_strdup(utf8_string);
-
-	plain_string=gtranslator_utf8_get_plain_string(&convert_me);
-	g_return_if_fail(plain_string!=NULL);
-
-	GTR_FREE(convert_me);
-
-	/*
-	 * We'll use our syntax highlighted insertion method also here .-)
-	 */
-	gtranslator_insert_text(GTK_TEXT(text), plain_string);
+	return (g_convert(str, -1, "UTF-8", po->header->charset, NULL, NULL, NULL));
 }
