@@ -1,5 +1,5 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,26 +40,8 @@ void gtranslator_utf8_convert_po_to_utf8(void);
 void gtranslator_utf8_convert_po_from_utf8(void);
 
 /*
- * Gets the UTF-8 part of the current string/message and ports it into "plain"
- *  form.
+ * Simple typing castration is shown in here...
  */
-gchar *gtranslator_utf8_get_plain_string(gchar **string); 
-gchar *gtranslator_utf8_get_plain_msgstr(GtrMsg **message); 
-
-/*
- * Get me the back to UTF-8!
- */
-gchar *gtranslator_utf8_get_utf8_string(gchar **string); 
-
-/*
- * Get/Set the GtkEntry/GtkText contents to UTF-8 and return the result.
- */
-gchar *gtranslator_utf8_get_gtk_entry_as_utf8_string(GtkWidget *entry);
-gchar *gtranslator_utf8_get_gtk_text_as_utf8_string(GtkWidget *text);
-
-void gtranslator_utf8_set_gtk_entry_from_utf8_string(GtkWidget *entry, 
-	const gchar *utf8_string);
-void gtranslator_utf8_set_gtk_text_from_utf8_string(GtkWidget *text,
-	const gchar *utf8_string);
+gchar *gtranslator_utf8_convert_to_utf8(const gchar *str);
 
 #endif
