@@ -1,5 +1,5 @@
 /*
- * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
@@ -35,9 +35,6 @@
 #include <unistd.h>
 
 #include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-util.h>
-
-#include <gal/util/e-util.h>
 
 /*
  * The used ref' count for the language lists.
@@ -56,7 +53,7 @@ GList *bits_list=NULL;
 /*
  * Strip the filename to get a "raw" enough filename.
  */ 
-gchar *gtranslator_utils_get_raw_file_name(gchar *filename)
+gchar *gtranslator_utils_get_raw_file_name(const gchar *filename)
 {
 	GString *o;
 	gint 	count=0;
@@ -137,7 +134,7 @@ gchar *gtranslator_utils_strip_all_punctuation_chars(const gchar *str)
 void gtranslator_utils_get_environment_value(const gchar *envpath, gchar **value)
 {
 	gint	i=0;
-	gchar	*contents=NULL;
+	const gchar	*contents=NULL;
 	gchar	**array=NULL;
 	
 	g_return_if_fail(envpath!=NULL);
@@ -277,7 +274,7 @@ void gtranslator_utils_remove_temp_files()
 	 * Check for any lungering 'round file rests of any temporary action
 	 *  and remove these rests if any had been found.
 	 */
-	if(g_file_exists(gtranslator_runtime_config->temp_filename))
+	if(g_file_test(gtranslator_runtime_config->temp_filename, G_FILE_TEST_EXISTS))
 	{
 		remove(gtranslator_runtime_config->temp_filename);
 	}
@@ -294,7 +291,6 @@ void gtranslator_utils_create_gtranslator_directory()
 	const	gchar	*subdirectories[] =
 	{
 		"colorschemes",
-		"etstates",
 		"files",
 		"umtf",
 		NULL
@@ -307,7 +303,7 @@ void gtranslator_utils_create_gtranslator_directory()
 	 */
 	if(!g_file_test(dirname, G_FILE_TEST_EXISTS))
 	{
-		if(e_mkdir_hier(dirname, 0755)==-1)
+		if(gtranslator_mkdir_hier(dirname, 0755)==-1)
 		{
 			g_warning(_("Can't create directory `%s'!"), dirname);
 			exit(1);
@@ -324,7 +320,7 @@ void gtranslator_utils_create_gtranslator_directory()
 
 		if(!g_file_test(dirname, G_FILE_TEST_EXISTS))
 		{
-			if(e_mkdir_hier(dirname, 0755)==-1)
+			if(gtranslator_mkdir_hier(dirname, 0755)==-1)
 			{
 				g_warning(_("Can't create directory `%s'!"), dirname);
 				exit(1);
@@ -408,7 +404,7 @@ void gtranslator_utils_get_compile_file_names(gchar **test_file,
 		g_get_home_dir());
 
 	*output_file=g_strdup_printf("%s/%s.gmo",
-		GtrPreferences.compile_output_dir, po->header->prj_name);
+		g_get_current_dir(), po->header->prj_name);
 }
 
 /*
@@ -479,47 +475,6 @@ gchar *gtranslator_utils_get_environment_locale()
 	return localename;
 }
 
-/*
- * Returns the "official" charset name for the currently active environment locale.
- */
-gchar *gtranslator_utils_get_environment_charset()
-{
-	gchar	*locale_name=NULL;
-	gchar	*locale_charset=NULL;
-
-	locale_name=gtranslator_utils_get_environment_locale();
-
-	if(!locale_name)
-	{
-		/*
-		 * Translators: this should be your default fall back encoding
-		 *  which will be used if gtranslator can't get the current env. locale's
-		 *   default sane encoding by itself.
-		 */
-		locale_charset=g_strdup(_("iso-8859-1"));
-	}
-	else if(!nautilus_strcasecmp(locale_name, "C") || !nautilus_strcasecmp(locale_name, "POSIX"))
-	{
-		locale_charset=g_strdup(_("iso-8859-1"));
-	}
-	else
-	{
-		gint c;
-
-		for(c=0; languages[c].name!=NULL; c++)
-		{
-			if(!nautilus_strcasecmp(languages[c].locale, locale_name))
-			{
-				locale_charset=g_strdup(languages[c].encoding);
-			}
-		}
-
-		GTR_FREE(locale_name);
-	}
-
-	return locale_charset;
-}
-
 /*
  * Subsequently filter out all extension containing filename from the directory.
  * 
@@ -1055,3 +1010,105 @@ gchar *gtranslator_utils_get_full_language_name(gchar *lang)
 		}
 	}
 }
+
+gint gtranslator_xml_get_integer_prop_by_name_with_default (const xmlNode *parent,
+	const xmlChar *prop_name, gint default_int)
+{
+	xmlChar *prop;
+	gint ret_val=default_int;
+
+	g_return_val_if_fail(parent!=NULL, 0);
+	g_return_val_if_fail(prop_name!=NULL, 0);
+
+	prop=xmlGetProp((xmlNode *) parent, prop_name);
+	
+	if(prop!=NULL)
+	{
+		(void) sscanf(prop, "%d", &ret_val);
+		xmlFree (prop);
+	}
+
+	return ret_val;
+}
+
+void gtranslator_xml_set_integer_prop_by_name (xmlNode *parent, const xmlChar *prop_name,
+	gint value)
+{
+	gchar *valuestr;
+
+	g_return_if_fail(parent!=NULL);
+	g_return_if_fail(prop_name!=NULL);
+
+	valuestr=g_strdup_printf("%d", value);
+	xmlSetProp(parent, prop_name, valuestr);
+	GTR_FREE(valuestr);
+}
+
+gchar *gtranslator_xml_get_string_prop_by_name_with_default(const xmlNode *parent,
+	const xmlChar *prop_name, const gchar *default_string)
+{
+	xmlChar *prop;
+	gchar *ret_val;
+
+	g_return_val_if_fail(parent!=NULL, 0);
+	g_return_val_if_fail(prop_name!=NULL, 0);
+
+	prop=xmlGetProp((xmlNode *) parent, prop_name);
+	
+	if(prop!=NULL)
+	{
+		ret_val=g_strdup(prop);
+		xmlFree(prop);
+	}
+	else
+	{
+		g_return_if_fail(default_string!=NULL);
+		ret_val=g_strdup (default_string);
+	}
+
+	return ret_val;
+}
+
+void gtranslator_xml_set_string_prop_by_name(xmlNode *parent, const xmlChar *prop_name,
+	const gchar *value)
+{
+	g_return_if_fail(parent!=NULL);
+	g_return_if_fail(prop_name!=NULL);
+
+	if(value!=NULL)
+	{
+		xmlSetProp(parent, prop_name, value);
+	}
+}
+
+int gtranslator_mkdir_hier(const char *path, mode_t mode)
+{
+        char *copy, *p;
+
+        p=copy=g_strdup (path);
+	
+        do
+	{
+                p=strchr(p + 1, '/');
+                if(p)
+		{
+                        *p='\0';
+		}
+		
+                if(access (copy, F_OK)==-1)
+		{
+                        if(mkdir(copy, mode)==-1)
+			{
+                                GTR_FREE(copy);
+                                return -1;
+                        }
+                }
+                if(p)
+		{
+                        *p='/';
+		}
+        } while(p);
+
+        GTR_FREE(copy);
+        return 0;
+}
